/*
 * LI18NUX2K.L1/base/bind_textdomain_codeset/bind_textdomain_codeset.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <locale.h>
#include <langinfo.h>
#include <libintl.h>
#include <iconv.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();

#define NO_TESTS 5
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	test5, 5,
	NULL, 0
};

private void
test1()
{
  int	  pathok = 0;
  char	  *posix_codeset, *ltp1_codeset;
  char	  *original = "Test1",  *correct, *temp;
  size_t  orig_left, crt_left = 32;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;
  iconv_t cv;

  DBUG_ENTER ("test1");
  tet_infoline ("When the codeset argument is a valid codeset name which can");
  tet_infoline ("be used for the iconv_open() function, verify that the");
  tet_infoline ("codeset of message outputted by gettext family is converted");
  tet_infoline ("into codeset argument.");
  tet_infoline (" ");

  setlocale (LC_ALL, "POSIX");
  posix_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (posix_codeset, nl_langinfo (CODESET));

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  ltp1_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (ltp1_codeset, nl_langinfo (CODESET));

  if ((cv = iconv_open (posix_codeset, ltp1_codeset)) == (iconv_t)(-1))
    {
      char msg[256];
      sprintf ("There is no converter from %s to %s.",
					ltp1_codeset, posix_codeset);
      xx_rpt (FAILURE);
      in_rpt (msg);
      DBUG_VOID_RETURN;
    }

  orig_left = strlen (original);
  temp = correct = (char *) calloc (crt_left, sizeof (char));

  if ((iconv (cv, &original, &orig_left, &temp, &crt_left)) == (size_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot convert a test string.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  bind_textdomain_codeset (dommainname, posix_codeset);
  textdomain (dommainname);

  if (strcmp (correct, gettext ("hello")) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("gettext got worng text. So bind_textdomain_codeset,");
      in_rpt ("bindtextdomain, textdomain or gettext works wrongly.");
    }

  free (posix_codeset);
  free (ltp1_codeset);
  free (correct);
  free (dirname);

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test2()
{
  int	  pathok = 0;
  char	  *posix_codeset, *ltp1_codeset;
  char	  *original = "Test1",  *correct, *temp;
  size_t  orig_left, crt_left = 32;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;
  iconv_t cv;

  DBUG_ENTER ("test2");
  tet_infoline ("When the codeset argument is a valid codeset name which can");
  tet_infoline ("be used for the iconv_open() function, verify that this");
  tet_infoline ("function returns a pointer to string which shows the valid");
  tet_infoline ("codeset argument.");
  tet_infoline (" ");

  setlocale (LC_ALL, "POSIX");
  posix_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (posix_codeset, nl_langinfo (CODESET));

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  ltp1_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (ltp1_codeset, nl_langinfo (CODESET));

  if ((cv = iconv_open (posix_codeset, ltp1_codeset)) == (iconv_t)(-1))
    {
      char msg[256];
      sprintf ("There is no converter from %s to %s.",
					ltp1_codeset, posix_codeset);
      xx_rpt (FAILURE);
      in_rpt (msg);
      DBUG_VOID_RETURN;
    }

  orig_left = strlen (original);
  temp = correct = (char *) calloc (crt_left, sizeof (char));

  if ((iconv (cv, &original, &orig_left, &temp, &crt_left)) == (size_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot convert a test string.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}
      dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  if (strcmp (bind_textdomain_codeset (dommainname, posix_codeset), posix_codeset) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The string returned by bind_textdomain_codeset is wrong.");
    }

  free (posix_codeset);
  free (ltp1_codeset);
  free (correct);
  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test3()
{
  int	  pathok = 0;
  char	  *posix_codeset, *ltp1_codeset;
  char	  *original = "Test1",  *correct, *temp;
  size_t  orig_left, crt_left = 32;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;
  iconv_t cv;

  DBUG_ENTER ("test3");
  tet_infoline ("When the codeset argument is NULL and the domain whose name");
  tet_infoline ("is domainname has been bound with a codeset already, verify");
  tet_infoline ("that this function returns the bided codeset name.");
  tet_infoline (" ");

  setlocale (LC_ALL, "POSIX");
  posix_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (posix_codeset, nl_langinfo (CODESET));

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  ltp1_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (ltp1_codeset, nl_langinfo (CODESET));

  if ((cv = iconv_open (posix_codeset, ltp1_codeset)) == (iconv_t)(-1))
    {
      char msg[256];
      sprintf ("There is no converter from %s to %s.",
					ltp1_codeset, posix_codeset);
      xx_rpt (FAILURE);
      in_rpt (msg);
      DBUG_VOID_RETURN;
    }

  orig_left = strlen (original);
  temp = correct = (char *) calloc (crt_left, sizeof (char));

  if ((iconv (cv, &original, &orig_left, &temp, &crt_left)) == (size_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot convert a test string.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  bind_textdomain_codeset (dommainname, posix_codeset);
  if (strcmp (bind_textdomain_codeset (dommainname, NULL), posix_codeset) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The string returned by bind_textdomain_codeset is wrong.");
    }

  free (posix_codeset);
  free (ltp1_codeset);
  free (correct);
  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test4()
{
  int	  pathok = 0;
  char	  *dommainname ="bar";

  DBUG_ENTER ("test4");
  tet_infoline ("When the codeset argument is NULL and the domain whose name");
  tet_infoline ("is domainname has not been binded with a codeset already,");
  tet_infoline ("verify that this function returns NULL.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  if (bind_textdomain_codeset (dommainname, NULL) == NULL)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The string returned by bind_textdomain_codeset is wrong.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test5()
{
  int	  pathok = 0;
  char	  *posix_codeset, *ltp1_codeset;
  char	  *original = "Test1",  *correct, *temp;
  size_t  orig_left, crt_left = 32;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;
  iconv_t cv;

  DBUG_ENTER ("test5");
  tet_infoline ("When this function applies for the domain whose name is");
  tet_infoline ("domainname several times, verify that the valid codeset");
  tet_infoline ("is the latter one.");
  tet_infoline (" ");

  setlocale (LC_ALL, "POSIX");
  posix_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (posix_codeset, nl_langinfo (CODESET));

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  ltp1_codeset = (char *) calloc (strlen (nl_langinfo(CODESET)) + 1, sizeof (char));
  strcpy (ltp1_codeset, nl_langinfo (CODESET));

  if ((cv = iconv_open (posix_codeset, ltp1_codeset)) == (iconv_t)(-1))
    {
      char msg[256];
      sprintf ("There is no converter from %s to %s.",
					ltp1_codeset, posix_codeset);
      xx_rpt (FAILURE);
      in_rpt (msg);
      DBUG_VOID_RETURN;
    }

  orig_left = strlen (original);
  temp = correct = (char *) calloc (crt_left, sizeof (char));

  if ((iconv (cv, &original, &orig_left, &temp, &crt_left)) == (size_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot convert a test string.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  bind_textdomain_codeset (dommainname, ltp1_codeset);
  bind_textdomain_codeset (dommainname, posix_codeset);
  if (strcmp (bind_textdomain_codeset (dommainname, NULL), posix_codeset) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The string returned by bind_textdomain_codeset is wrong.");
    }

  free (posix_codeset);
  free (ltp1_codeset);
  free (correct);
  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
