/*
 * LI18NUX2K.L1/base/bindtextdomain/bindtextdomain.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <locale.h>
#include <libintl.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();

#define NO_TESTS 6
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	test5, 5,
	test6, 6,
	NULL, 0
};

private void
test1()
{
  int	  pathok = 0;
  char	  *correct = "あ¢test1";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test1");
  tet_infoline ("Verify that this function specifies that the domainname");
  tet_infoline ("message catalog will be found in the dirname directory");
  tet_infoline ("hierarchy.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }

  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  textdomain (dommainname);

  if (strcmp (correct, gettext ("hello")) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("gettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or gettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


private void
test2()
{
  int	  pathok = 0;
  char	  *correct = "い¢test2";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test2");
  tet_infoline ("Veirfy that this function applies domainname to the currently");
  tet_infoline ("active LC_MESSAGES locale.");
  tet_infoline (" ");

  setlocale (LC_ALL, "en_US");
  if (setlocale(LC_MESSAGES, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }

  strcat (dirname, "/test2");

  bindtextdomain (dommainname, dirname);
  textdomain (dommainname);

  if (strcmp (correct, gettext ("hello")) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("gettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or gettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


private void
test3()
{
  int	  pathok = 0;
  char	  *correct = "う¢test3";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test3");
  tet_infoline ("Verify that this function specifies the message even if the");
  tet_infoline ("dirname directory is absolute pathname.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }

  strcat (dirname, "/test3");

  bindtextdomain (dommainname, dirname);
  textdomain (dommainname);

  if (strcmp (correct, gettext ("hello")) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("gettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or gettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test4()
{
  int	  pathok = 0;
  char	  *correct = "え¢test4";
  char	  *dommainname ="foo";

  DBUG_ENTER ("test4");
  tet_infoline ("Verify that this function specifies the message even if the");
  tet_infoline ("dirname directory is relative pathname.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  bindtextdomain (dommainname, "../test4");
  textdomain (dommainname);

  if (strcmp (correct, gettext ("hello")) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("gettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or gettext works wrongly.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test5()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test5");
  tet_infoline ("When this function specifies the message correctly, verify");
  tet_infoline ("this function returns the pointer to the string which shows");
  tet_infoline ("the directory pathname currently bound to the domain.");


  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }

  strcat (dirname, "/test5");

  if (strcmp (dirname, bindtextdomain (dommainname, dirname)) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test6()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test6");
  tet_infoline ("When this function does not specify the message correctly,");
  tet_infoline ("verify this function returns NULL.");

  xx_rpt (UNTESTED);
  in_rpt ("Cannot make the situation.");
  DBUG_VOID_RETURN;
}
