/*
 * LI18NUX2K.L1/base/dngettext/dngettext.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <locale.h>
#include <langinfo.h>
#include <libintl.h>
#include <iconv.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();
private void test7();
private void test8();
private void test9();
private void test10();
private void test11();

#define NO_TESTS 11
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	test5, 5,
	test6, 6,
	test7, 7,
	test8, 8,
	test9, 9,
	test10, 10,
	test11, 11,
	NULL, 0
};

private void
test1()
{
  int	  pathok = 0;
  char	  *correct = "てすと¢0¢";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test1");
  tet_infoline ("Verify that this function locates the message according to");
  tet_infoline ("the string pointed by domainname.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "hello", "good bye", 1);
  if (strcmp (correct, p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test2()
{
  int	  pathok = 0;
  char	  *correct = "てすと¢0¢";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test2");
  tet_infoline ("If LANGUAGE environment variable is defined and the value is");
  tet_infoline ("a locale name, verify that this function uses the localename");
  tet_infoline ("to determine the message catalog.");
  tet_infoline (" ");
  
  if (setlocale(LC_ALL, "VSX4L0") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use VSX4L0 locale.");
      DBUG_VOID_RETURN;
    }

  if (setlocale(LC_CTYPE, "LTP_1.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_1.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  putenv ("LANGUAGE=LTP_1.UTF-8");

  p = dngettext (dommainname, "hello", "good bye", 1);
  if (strcmp (correct, p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test3()
{
  int	  pathok = 0;
  char	  *correct = "てすと¢0¢";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test3");
  tet_infoline ("If LANGUAGE environment variable is defined and the value");
  tet_infoline ("is a list of locale name separated by `:' character, verify");
  tet_infoline ("that this function searches the message sequentially from the");
  tet_infoline ("top of that list.");
  tet_infoline (" ");

  if (setlocale(LC_ALL, "VSX4L0") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use VSX4L0 locale.");
      DBUG_VOID_RETURN;
    }

  if (setlocale(LC_CTYPE, "LTP_1.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_1.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  putenv ("LANGUAGE=VSX4L0:LTP_1.UTF-8:VSX4L1");

  p = dngettext (dommainname, "hello", "good bye", 1);
  if (strcmp (correct, p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test4()
{
  int	  pathok = 0;
  char	  *correct = "てすと¢0¢";
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test4");
  tet_infoline ("If LANGUAGE environment variable is defined and this function");
  tet_infoline ("can locate the message according to the msgid1, verify that");
  tet_infoline ("this function returns a pointer to the located message.");
  tet_infoline (" ");
  
  if (setlocale(LC_ALL, "VSX4L0") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use VSX4L0 locale.");
      DBUG_VOID_RETURN;
    }

  if (setlocale(LC_CTYPE, "LTP_1.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_1.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  putenv ("LANGUAGE=LTP_1.UTF-8");

  p = dngettext (dommainname, "hello", "good bye", 1);
  if (strcmp (correct, p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test5()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test5");
  tet_infoline ("If LANGUAGE environment variable is defined, the value of n");
  tet_infoline ("is 1 and this function cannot locate the message according to");
  tet_infoline ("the msgid1, verify that this function returns msgid1.");
  tet_infoline (" ");
  
  if (setlocale(LC_ALL, "VSX4L0") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use VSX4L0 locale.");
      DBUG_VOID_RETURN;
    }

  if (setlocale(LC_CTYPE, "LTP_1.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_1.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  putenv ("LANGUAGE=LTP_1.UTF-8");

  p = dngettext (dommainname, "good morning", "good bye", 1);
  if (strcmp ("good morning", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test6()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test6");
  tet_infoline ("If LANGUAGE environment variable is defined, the value of n");
  tet_infoline ("is not 1 and this function cannot locate the message according");
  tet_infoline ("to the msgid1, verify that this function returns msgid2.");
  tet_infoline (" ");
  
  if (setlocale(LC_ALL, "VSX4L0") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use VSX4L0 locale.");
      DBUG_VOID_RETURN;
    }

  if (setlocale(LC_CTYPE, "LTP_1.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_1.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);
  putenv ("LANGUAGE=LTP_1.UTF-8");

  p = dngettext (dommainname, "good morning", "good bye", 2);
  if (strcmp ("good bye", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test7()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *correct = "てすと¢0¢";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test7");
  tet_infoline ("If LANGUAGE environment variable is not defined, verify that");
  tet_infoline ("this function searches the message according to the LC_ALL,");
  tet_infoline ("LC_xxx, and LANG environment variables.");
  tet_infoline (" ");
  
  putenv ("LC_ALL=LTP_1.UTF-8");
  if (setlocale(LC_ALL, "") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "hello", "good bye", 1);
  if (strcmp (correct, p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test8()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test8");
  tet_infoline ("If LANGUAGE environment variable is not defined, the value of");
  tet_infoline ("n is 1, and this function cannot locate the message according");
  tet_infoline ("to the LC_ALL, LC_xxx, and LANG environment variables, verify");
  tet_infoline ("that this function returns msgid1.");
  tet_infoline (" ");
  
  putenv ("LC_ALL=LTP_1.UTF-8");
  if (setlocale(LC_ALL, "") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "good morning", "good bye", 1);
  if (strcmp ("good morning", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test9()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test9");
  tet_infoline ("If LANGUAGE environment variable is not defined, the value of");
  tet_infoline ("n is not 1, and this function cannot locate the message");
  tet_infoline ("according to the LC_ALL, LC_xxx, and LANG environment");
  tet_infoline ("variables, verify that this function returns msgid2.");
  tet_infoline (" ");
  
  putenv ("LC_ALL=LTP_1.UTF-8");
  if (setlocale(LC_ALL, "") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "good morning", "good bye", 2);
  if (strcmp ("good bye", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test10()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test10");
  tet_infoline ("If the LC_MESSAGES locale category of the current locale is");
  tet_infoline ("the standard C locale or the standard POSIX locale and the");
  tet_infoline ("value of n is 1, verify that this function returns msgid1.");
  tet_infoline (" ");
  
  setlocale(LC_ALL, "POSIX");

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "hello", "good bye", 1);

  if (strcmp ("hello", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

private void
test11()
{
  int	  pathok = 0;
  char	  *dommainname ="foo";
  char	  *dirname = NULL;
  char	  *p;
  size_t  dirnamelen = 16;

  DBUG_ENTER ("test11");
  tet_infoline ("If the LC_MESSAGES locale category of the current locale is");
  tet_infoline ("the standard C locale or the standard POSIX locale and the");
  tet_infoline ("value of n is 2, verify that this function returns msgid2.");
  tet_infoline (" ");
  
  setlocale(LC_ALL, "POSIX");

  globok = 1;

  for (;;)
    {
      if ((dirname = (char *)realloc (dirname, dirnamelen + 8)) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("There is not enough memory.");
	  DBUG_VOID_RETURN;
	}
      memset (dirname, '\0', dirnamelen + 8);

      if ((getcwd (dirname, dirnamelen)) != NULL)
	{
	  char *p;
	  p = strrchr (dirname, '/');
	  *p = '\0';
	  break;
	}

      else
	dirnamelen += 16;
    }


  strcat (dirname, "/test1");

  bindtextdomain (dommainname, dirname);

  p = dngettext (dommainname, "hello", "good bye", 2);

  if (strcmp ("good bye", p) == 0)
    PATH_TRACE;
  else
    {
      char msg[1024];

      xx_rpt (FAILURE);
      in_rpt ("dngettext got worng text.");
      in_rpt ("So bindtextdomain, textdomain or dngettext works wrongly.");
    }

  free (dirname);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
