/*
 * LI18NUX2K.L1/base/fgetws/fgetws.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <errno.h>
#include <locale.h>
#include <wchar.h>


private char *test_locale = "LTP_1.UTF-8";

#define	CHAR_NUM  4
#define STR_NUM   2
private wchar_t wstr[][CHAR_NUM + 1] = {{L'A', 0x00C4, 0x3042, L'\n', L'\0'},
			                {0x00C4, 0x3042, L'A', L'\n', L'\0'}};
private char *str[STR_NUM]  = {"AÄあ", "ÄあA"};

#define INVALID_BYTE_LEN  4
private char invalid_str[INVALID_BYTE_LEN + 1] = {'a', 0xe3, 0x21, '\n', '\0'}; 

private void test1();
private void test2();
private void test3();
private void test4();
private int  is_wcs_same (const wchar_t *ws1, const wchar_t *ws2, size_t n);

#define NO_TESTS 4
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,  1,
	test2,  2,
	test3,  3,
	test4,  4,
	NULL, 0
};


/* If the byte sequence which starts at the file position indicator stands is
   valid as a multibyte character string on the current locale, verify this
   function returns s, and sets a wide character string at s. The wide
   character string is equivalent to the multibyte character string and
   appends a null wide character at the end of the wide character string. */
private void
test1()
{
  int i;
  wchar_t ws[CHAR_NUM * 2], *ret;
  FILE *fp;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the byte sequence which starts at the file position "
	       "indicator stands is valid as a multibyte character string "
	       "on the current locale, verify this function returns s, and "
	       "sets a wide character string at s. The wide character string "
	       "is equivalent to the multibyte character string and appends "
	       "a null wide character at the end of the wide character "
	       "string.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < STR_NUM; i++)
    fprintf (fp, "%s\n", str[i]);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  for (i = 0; i < STR_NUM; i++)
    {
      ret = fgetws (ws, CHAR_NUM * 2, fp);

      if (ret == ws && is_wcs_same (wstr[i], ws, CHAR_NUM + 1))
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("fgets() did not get a wide character string correctry.");
	  DBUG_PRINTF ("test1", "String: %ls != %ls", ws, wstr[i]);
	}
    }

  fclose (fp);

  PATH_XS_RPT(STR_NUM);
  DBUG_VOID_RETURN;
}


/* If the byte sequence which starts at the file position indicator stands is
   invalid as a multibyte character string on the current locale, verify this
   function returns NULL. */ 
private void
test2()
{
  int i;
  wchar_t ws[CHAR_NUM * 2], *ret;
  FILE *fp;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the byte sequence which starts at the file position "
	       "indicator stands is invalid as a multibyte character string "
	       "on the current locale, verify this function returns NULL.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  fwrite (invalid_str, sizeof(char), INVALID_BYTE_LEN, fp);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fgetws (ws, INVALID_BYTE_LEN * 3, fp);

  if (ret == NULL)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
      DBUG_PRINTF ("test2", "STR: %s", ret);
    }

  fclose (fp);

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If the file position indicator stands at end-of-file, verify this function
   returns NULL. */
private void
test3()
{
  int i;
  wchar_t ws[CHAR_NUM * 2], *ret;
  FILE *fp;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the file position indicator stands at end-of-file, verify "
	       "this function returns NULL.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fgetws (ws, CHAR_NUM * 2, fp);
  if (ret == NULL)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  fclose (fp);
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* After executing this function correctly, verify the type of stream is
   changed to wide character oriented. */
private void
test4()
{
  wchar_t ws[CHAR_NUM * 2], *ret;
  FILE *fp;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "After executing this function correctly, verify the type "
	       "of stream is changed to wide character oriented.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  fprintf (fp, "%s", str[0]);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fgetws (ws, CHAR_NUM * 2, fp);

  if (fwide(fp, 0) > 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The stream type is changed by a mistake.");
    }

  fclose (fp);

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}



/* compare two arrays of wide characters.
   If two array is the same, this function returns 1, others returns 0. */
  private int
is_wcs_same (const wchar_t *ws1, const wchar_t *ws2, size_t n)
{
  int i;

  for (i = 0; i < n; i++)
    if (ws1[i] != ws2[i])
      return 0;

  return 1;
}
