/*
 * LI18NUX2K.L1/base/fscanf/fscanf.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <locale.h>
#include <wchar.h>

#define WCS_LEN_MAX 32

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();

#define NO_TESTS 6
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,   1,
	test2,   2,
	test3,   3,
	test4,   4,
	test5,   5,
	test6,   6,
	NULL,    0
};


/* If format has `e', `E', `f', `g' or `G' flag, verify this function
   correctly interprets the radix character according to the current
   locale. */
private void
test1()
{
  FILE *fp;
  int  i, num, ret;
  double fract;
  char *conv[] = {"%le",   "%lE",   "%lf",   "%lg",   "%lG"};
  char *str[]  = {"1*234", "5*678", "9*012", "34*56", "78*90"};
  double ans[] = { 1.234,   5.678,   9.012,   34.56,   78.9};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If format has `e', `E', `f', `g' or `G' flag, verify this "
	       "function correctly interprets the radix character according "
	       "to the current locale.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(conv) / sizeof(conv[0]);

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < num; i++)
    {
      DBUG_PRINTF ("test1", "str[%d]: %s", i, str[i]);
      fprintf (fp, " %s", str[i]);
    }
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

 for (i = 0; i < num; i++)
   {
     ret = fscanf (fp, conv[i], &fract);

     if (fract == ans[i])
       PATH_TRACE;
     else
       {
	 xx_rpt (FAILURE);
	 in_rpt ("The radix caracter is not interpreted correctly.");
	 DBUG_PRINTF ("test1", "fraction[%d] = %f", i, fract);
       }
   }

 fclose (fp);

  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* If a conversion character is `c' and conversion specification has `l',
   verify this function reads a sequence of the multibyte characters of the
   number specified by the field width, and stores the wide character
   sequence as same that are made of the sequence of the multibyte characters
   by mbsrtowcs() with initial conversion state. */
private void
test2()
{
  FILE *fp;
  int  i, num, ret;
  wchar_t wcs1[WCS_LEN_MAX], wcs2[WCS_LEN_MAX];
  char *ps;
  const char **pps;
  size_t wcslen1, wcslen2;
  mbstate_t state;
  char *conv[] = {"%3lc"};
  char *str[]  = {"AÄあAÄあ"};
  size_t len[] = {3};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If a conversion character is `c' and conversion specification "
	       "has `l', verify this function reads a sequence of the "
	       "multibyte characters of the number specified by the field "
	       "width, and stores the wide character sequence as same that "
	       "are made of the sequence of the multibyte characters by "
	       "mbsrtowcs() with initial conversion state.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(conv) / sizeof(conv[0]);

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < num; i++)
    {
      DBUG_PRINTF ("test2", "str[%d]: %s", i, str[i]);
      fprintf (fp, "%s", str[i]);
    }
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  for (i = 0; i < num; i++)
    {
      wmemset (wcs1, L'\0', WCS_LEN_MAX);
      ret = fscanf (fp, conv[i], wcs1);
      DBUG_PRINTF ("test2", "(fscanf)   : %ls", wcs1);
      wcslen1 = wcslen (wcs1);

      wmemset (wcs2, L'\0', WCS_LEN_MAX);
      ps  = str[i];
      pps = (const char **)&ps;
      memset (&state, '\0', sizeof(mbstate_t));
      wcslen2 = mbsrtowcs (wcs2, pps, len[i], &state);
      DBUG_PRINTF ("test2", "(mbsrtowcs): %ls", wcs2);

      if (wmemcmp (wcs1, wcs2, (wcslen1 > wcslen2 ? wcslen1 : wcslen2)) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier `%%lc' is not interpreted correctry");
	  DBUG_PRINTF ("test2", "wcs[%d] = %ls", i, wcs1);
	}
    }
  fclose (fp);

  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* If a conversion character is `s' and conversion specification has `l',
   verify this function reads a multibyte character string, and stores the
   wide character string as same that are made of the multibyte character
   string by mbsrtowcs() with initial conversion state. Especially check the
   null wide character is stood at the end of the wide character string. */
private void
test3()
{
  FILE *fp;
  int  i, num, ret;
  wchar_t wcs1[WCS_LEN_MAX], wcs2[WCS_LEN_MAX];
  char *ps;
  const char **pps;
  size_t wcslen1, wcslen2;
  mbstate_t state;
  char *conv[] = {"%ls"};
  char *str[]  = {"AÄあAÄあ"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If a conversion character is `s' and conversion specification "
	       "has `l', verify this function reads a multibyte character "
	       "string, and stores the wide character string as same that are "
	       "made of the multibyte character string by mbsrtowcs() with "
	       "initial conversion state. Especially check the null wide "
	       "character is stood at the end of the wide character string.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(conv) / sizeof(conv[0]);

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < num; i++)
    {
      DBUG_PRINTF ("test3", "str[%d]: %s", i, str[i]);
      fprintf (fp, "%s", str[i]);
    }
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  for (i = 0; i < num; i++)
    {
      /* For Checking whether this function attached terminated null
	 wide character. */
      wmemset (wcs1, L'X', WCS_LEN_MAX);
      wcs1[WCS_LEN_MAX - 1] = L'\0';

      ret = fscanf (fp, conv[i], wcs1);
      DBUG_PRINTF ("test3", "(fscanf)   : %ls", wcs1);
      wcslen1 = wcslen (wcs1);

      wmemset (wcs2, L'\0', WCS_LEN_MAX);
      ps  = str[i];
      pps = (const char **)&ps;
      memset (&state, '\0', sizeof(mbstate_t));
      wcslen2 = mbsrtowcs (wcs2, pps, WCS_LEN_MAX, &state);
      DBUG_PRINTF ("test3", "(mbsrtowcs): %ls", wcs2);

      if (wmemcmp (wcs1, wcs2, (wcslen1 > wcslen2 ? wcslen1 : wcslen2)) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier `%%ls' is not interpreted correctry");
	  DBUG_PRINTF ("test3", "wcs[%d] = %ls", i, wcs1);
	}
    }
  fclose (fp);

  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* If the conversion specifier is `l[ ]', verify this function reads a
   sequence of bytes which is included between `[' and `]', and stores the
   wide character sequence as same as that are made of the sequence of the
   multibyte characters by mbsrtowcs() with initial conversion state.
   Especially check the null wide character is stood at the end of the wide
   character string. */
private void
test4()
{
  FILE *fp;
  int  i, num, ret;
  wchar_t wcs1[WCS_LEN_MAX];
  char *ps, **pps;
  size_t wcslen1, anslen;
  mbstate_t state;
  char *conv[] = {"%l[ABC]"};
  char *str[]  = {"ABBCDDCC"};
  wchar_t ans[] = {L'A', L'B', L'B', L'C', L'\0'};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion specifier is `l[ ]', verify this function "
	       "reads a sequence of bytes which is included between `[' and "
	       "`]', and stores the wide character sequence as same as that "
	       "are made of the sequence of the multibyte characters by "
	       "mbsrtowcs() with initial conversion state. Especially check "
	       "the null wide character is stood at the end of the wide "
	       "character string.";


  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(conv) / sizeof(conv[0]);

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < num; i++)
    {
      DBUG_PRINTF ("test4", "str[%d]: %s", i, str[i]);
      fprintf (fp, "%s", str[i]);
    }
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  for (i = 0; i < num; i++)
    {
      /* For Checking whether this function attached terminated null
	 wide character. */
      wmemset (wcs1, L'X', WCS_LEN_MAX);
      wcs1[WCS_LEN_MAX - 1] = L'\0';

      ret = fscanf (fp, conv[i], wcs1);
      wcslen1 = wcslen (wcs1);
      DBUG_PRINTF ("test4", "wcs1: %ls", wcs1);
      
      anslen  = wcslen (ans);
      DBUG_PRINTF ("test4", "ans : %ls", ans);

      if (wmemcmp (wcs1, ans, (wcslen1 > anslen ? wcslen1 : anslen)) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier `%%ls' is not interpreted correctry");
	  DBUG_PRINTF ("test4", "wcs[%d] = %ls", i, wcs1);
	}
    }
  fclose (fp);

  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* If the conversion specifier is `l[^ ]', verify this function reads a
   sequence of bytes which is not included between `[^' and `]', and stores
   the wide character sequence as same as that are made of the sequence of
   the multibyte characters by mbsrtowcs() with initial conversion state.
   Especially check the null wide character is stood at the end of the wide
   character string. */
private void
test5()
{
  FILE *fp;
  int  i, num, ret;
  wchar_t wcs1[WCS_LEN_MAX];
  char *ps, **pps;
  size_t wcslen1, anslen;
  mbstate_t state;
  char *conv[] = {"%l[^DEF]"};
  char *str[]  = {"ABBCDDCC"};
  wchar_t ans[] = {L'A', L'B', L'B', L'C', L'\0'};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion specifier is `l[^ ]', verify this function "
	       "reads a sequence of bytes which is not included between `[^' "
	       "and `]', and stores the wide character sequence as same as "
	       "that are made of the sequence of the multibyte characters by "
	       "mbsrtowcs() with initial conversion state. Especially check "
	       "the null wide character is stood at the end of the wide "
	       "character string.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(conv) / sizeof(conv[0]);

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  for (i = 0; i < num; i++)
    {
      DBUG_PRINTF ("test5", "str[%d]: %s", i, str[i]);
      fprintf (fp, "%s", str[i]);
    }
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  for (i = 0; i < num; i++)
    {
      /* For Checking whether this function attached terminated null
	 wide character. */
      wmemset (wcs1, L'X', WCS_LEN_MAX);
      wcs1[WCS_LEN_MAX - 1] = L'\0';

      ret = fscanf (fp, conv[i], wcs1);
      wcslen1 = wcslen (wcs1);
      DBUG_PRINTF ("test5", "wcs1: %ls", wcs1);
      
      anslen  = wcslen (ans);
      DBUG_PRINTF ("test5", "ans : %ls", ans);

      if (wmemcmp (wcs1, ans, (wcslen1 > anslen ? wcslen1 : anslen)) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier `%%ls' is not interpreted correctry");
	  DBUG_PRINTF ("test5", "wcs[%d] = %ls", i, wcs1);
	}
    }
  fclose (fp);

  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* After executing this function correctly, verify the stream is changed to
   byte oriented. */
private void
test6()
{
  FILE *fp;
  int  ret, n;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "After executing this function correctly, verify the stream is "
	       "changed to byte oriented.";

  DBUG_ENTER ("test6");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  fprintf (fp, "9abc");
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fscanf (fp, "%d", &n);

  if (fwide(fp, 0) < 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The stream type is changed by a mistake.");
    }
  fclose (fp);

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

