/*
 * LI18NUX2K.L1/base/iconv/iconv.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <locale.h>
#include <wchar.h>
#include <wctype.h>
#include <langinfo.h>
#include <iconv.h>
#include <errno.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();

#define NO_TESTS 4
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	NULL, 0
};

/* If this function converts the entire string in the input buffer, verify
   the value pointed to by inbytesleft will be 0.  */
private void
test1()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If this function converts the entire string in the input "
               "buffer, verify the value pointed to by inbytesleft will be 0.";
  char *from, *to, *pin, *pout;
  char out[256];
  iconv_t idesc;
  size_t rval, inleft, outleft;

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  from = nl_langinfo(CODESET);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  to = nl_langinfo(CODESET);

  if (from == NULL || to == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("nl_langinfo failed.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  idesc = iconv_open(to, from);

  if (idesc == (iconv_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("iconv_open failed.");
      DBUG_VOID_RETURN;
    }

  pin = "input string";
  inleft = strlen(pin);
  pout = out;
  outleft = 256;
  rval = iconv(idesc, &pin, &inleft, &pout, &outleft);

  if (rval == 0)
    {
      if (inleft == 0)
        PATH_TRACE;
      else
        {
          xx_rpt (FAILURE);
          in_rpt ("inbytesleft must be 0.");
          DBUG_VOID_RETURN;
        }
    }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("Can't convert the entire input by iconv().");
      DBUG_VOID_RETURN;
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

/* If the input conversion is stopped, verify the value pointed to by
   inbytesleft will be non-zero and errno is set to indicate the condition.
*/
private void
test2()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the input conversion is stopped, verify the value "
               "pointed to by inbytesleft will be non-zero and errno is "
               "set to indicate the condition.";
  char *from, *to, *pin, *pout;
  char out[256];
  iconv_t idesc;
  size_t rval, inleft, outleft;

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  from = nl_langinfo(CODESET);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  to = nl_langinfo(CODESET);

  if (from == NULL || to == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("nl_langinfo failed.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  idesc = iconv_open(to, from);

  if (idesc == (iconv_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("iconv_open failed.");
      DBUG_VOID_RETURN;
    }

  pin = "invalid\376";
  inleft = strlen(pin);
  pout = out;
  outleft = 256;
  rval = iconv(idesc, &pin, &inleft, &pout, &outleft);

  if (rval == 0)
    {
      xx_rpt (FAILURE);
      in_rpt ("Unexpect conversion.");
      DBUG_VOID_RETURN;
    }
  else
    {
      if (inleft == 0)
        {
          xx_rpt (FAILURE);
          in_rpt ("inbytesleft must be non-zero.");
          DBUG_VOID_RETURN;
        }
      else
        {
          if (errno == EILSEQ)
            PATH_TRACE;
          else
            {
              xx_rpt (FAILURE);
              in_rpt ("errno must be EILSEQ.");
              DBUG_VOID_RETURN;
            }
        }
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If an error occurs, verify this function returns (size_t)-1 and sets
   errno to indicate the error.  */
private void
test3()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If an error occurs, verify this function returns (size_t)-1 "
	       "and sets errno to indicate the error.";
  char *from, *to, *pin, *pout;
  char out[256];
  iconv_t idesc;
  size_t rval, inleft, outleft;

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  pin = "dummy";
  inleft = strlen(pin);
  pout = out;
  outleft = 256;
  rval = iconv((iconv_t)-1, &pin, &inleft, &pout, &outleft);

  if (rval == 0)
    {
      xx_rpt (FAILURE);
      in_rpt ("(iconv_t)-1 must be invalid.");
      DBUG_VOID_RETURN;
    }
  else
    {
      if (errno == EBADF)
        PATH_TRACE;
      else
        {
          xx_rpt (FAILURE);
          in_rpt ("errno must be EBADF.");
          DBUG_VOID_RETURN;
        }
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}

/* If the output buffer is not large enough to hold the entire reset
   sequence, verify iconv() will fail and set errno to [E2BIG].  */
private void
test4()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the output buffer is not large enough to hold the "
               "entire reset sequence, verify iconv() will fail and set "
               "errno to [E2BIG].";
  char *from, *to, *pin, *pout;
  char out[256];
  iconv_t idesc;
  size_t rval, inleft, outleft;

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  from = nl_langinfo(CODESET);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  to = nl_langinfo(CODESET);

  if (from == NULL || to == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("nl_langinfo failed.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  idesc = iconv_open(to, from);

  if (idesc == (iconv_t)-1)
    {
      xx_rpt (FAILURE);
      in_rpt ("iconv_open failed.");
      DBUG_VOID_RETURN;
    }

  pin = "dummy";
  inleft = strlen(pin);
  pout = out;
  outleft = 1;
  rval = iconv(idesc, &pin, &inleft, &pout, &outleft);

  if (rval == 0)
    {
      xx_rpt (FAILURE);
      in_rpt ("Invalid success.");
      DBUG_VOID_RETURN;
    }
  else
    {
      if (errno == E2BIG)
        PATH_TRACE;
      else
        {
          xx_rpt (FAILURE);
          in_rpt ("errno must be E2BIG.");
          DBUG_VOID_RETURN;
        }
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
