/*
 * LI18NUX2K.L1/base/localeconv/localeconv.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <locale.h>
#include <wchar.h>
#include <wctype.h>

#define UNICODE_MAX 0xFFFF

private char *test_locale = "LTP_1.UTF-8";

private char *def_decimal_point     = "*";
private char *def_thousands_sep     = "|";
private char def_grouping[]         = {1, 2, 1};
private char *def_int_curr_symbol   = "FUN ";
private char *def_currency_symbol   = "♪";
private char *def_mon_decimal_point = "*";
private char *def_mon_thousands_sep = "|";
private char def_mon_grouping[]     = {1, 2};
private char *def_positive_sign     = "▲";
private char *def_negative_sign     = "▽";
private char def_int_frac_digits    = 0;
private char def_frac_digits        = 0;
private char def_p_cs_precedes      = 1;
private char def_p_sep_by_space     = 0;
private char def_n_cs_precedes      = 1;
private char def_n_sep_by_space     = 0;
private char def_p_sign_posn        = 1;
private char def_n_sign_posn        = 1;

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();
private void test7();
private void test8();
private void test9();
private void test10();
private void test11();
private void test12();
private void test13();
private void test14();
private void test15();
private void test16();
private void test17();
private void test18();

#define NO_TESTS 18
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,  1,
	test2,  2,
	test3,  3,
	test4,  4,
	test5,  5,
	test6,  6,
	test7,  7,
	test8,  8,
	test9,  9,
	test10, 10,
	test11, 11,
	test12, 12,
	test13, 13,
	test14, 14,
	test15, 15,
	test16, 16,
	test17, 17,
	test18, 18,
	NULL, 0
};


/* Verify this function sets the struct lconv member *decimal_point according
   to the current locale. */
private void
test1()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*decimal_point according to the current locale.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->decimal_point, def_decimal_point) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *decimal_point is not correct.");
      DBUG_PRINTF ("test1", "decimal_point: %s", lconv_p->decimal_point);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *thousands_sep according
   to the current locale. */
private void
test2()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*thousands_sep according to the current locale.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->thousands_sep, def_thousands_sep) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *thousands_sep is not correct.");
      DBUG_PRINTF ("test2", "thousands_sep: %s", lconv_p->thousands_sep);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *grouping according
   to the current locale. */
private void
test3()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*grouping according to the current locale.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (memcmp (lconv_p->grouping, def_grouping, 3) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *grouping is not correct.");
      DBUG_PRINTF ("test3", "grouping: %d", *(lconv_p->grouping));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *int_curr_symbol
   according to the current locale. */
private void
test4()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*int_curr_symbol according to the current locale.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->int_curr_symbol, def_int_curr_symbol) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *int_curr_symbol is not correct.");
      DBUG_PRINTF ("test4", "int_curr_symbol: %d", *(lconv_p->int_curr_symbol));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *currency_symbol
   according to the current locale. */
private void
test5()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*currency_symbol according to the current locale.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->currency_symbol, def_currency_symbol) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *currency_symbol is not correct.");
      DBUG_PRINTF ("test5", "currency_symbol: %d", *(lconv_p->currency_symbol));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *mon_decimal_point
   according to the current locale. */
private void
test6()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*mon_decimal_point according to the current locale.";

  DBUG_ENTER ("test6");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->mon_decimal_point, def_mon_decimal_point) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *mon_decimal_point is not correct.");
      DBUG_PRINTF ("test6", "mon_decimal_point: %d", *(lconv_p->mon_decimal_point));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *mon_thousands_sep
   according to the current locale. */
private void
test7()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*mon_thousands_sep according to the current locale.";

  DBUG_ENTER ("test7");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->mon_thousands_sep, def_mon_thousands_sep) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *mon_thousands_sep is not correct.");
      DBUG_PRINTF ("test7", "mon_thousands_sep: %d", *(lconv_p->mon_thousands_sep));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *mon_grouping according
   to the current locale. */
private void
test8()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*mon_grouping according to the current locale.";

  DBUG_ENTER ("test8");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (memcmp (lconv_p->mon_grouping, def_mon_grouping, 2) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *mon_grouping is not correct.");
      DBUG_PRINTF ("test8", "mon_grouping: %d", *(lconv_p->mon_grouping));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *positive_sign
   according to the current locale. */
private void
test9()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*positive_sign according to the current locale.";

  DBUG_ENTER ("test9");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->positive_sign, def_positive_sign) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *positive_sign is not correct.");
      DBUG_PRINTF ("test9", "positive_sign: %d", *(lconv_p->positive_sign));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member *negative_sign
   according to the current locale. */
private void
test10()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "*negative_sign according to the current locale.";

  DBUG_ENTER ("test10");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (strcmp (lconv_p->negative_sign, def_negative_sign) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member *negative_sign is not correct.");
      DBUG_PRINTF ("test10", "negative_sign: %d", *(lconv_p->negative_sign));
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member int_frac_digits according
   to the current locale. */
private void
test11()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "int_frac_digits according to the current locale.";

  DBUG_ENTER ("test11");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->int_frac_digits == def_int_frac_digits)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member int_frac_digits is not correct.");
      DBUG_PRINTF ("test11", "int_frac_digits: %d", lconv_p->int_frac_digits);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member frac_digits according
   to the current locale. */
private void
test12()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "frac_digits according to the current locale.";

  DBUG_ENTER ("test12");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->frac_digits == def_frac_digits)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member frac_digits is not correct.");
      DBUG_PRINTF ("test12", "frac_digits: %d", lconv_p->frac_digits);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member p_cs_precedes according
   to the current locale. */
private void
test13()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "p_cs_precedes according to the current locale.";

  DBUG_ENTER ("test13");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->p_cs_precedes == def_p_cs_precedes)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member p_cs_precedes is not correct.");
      DBUG_PRINTF ("test13", "p_cs_precedes: %d", lconv_p->p_cs_precedes);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member p_sep_by_space according
   to the current locale. */
private void
test14()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "p_sep_by_space according to the current locale.";

  DBUG_ENTER ("test14");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->p_sep_by_space == def_p_sep_by_space)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member p_sep_by_space is not correct.");
      DBUG_PRINTF ("test14", "p_sep_by_space: %d", lconv_p->p_sep_by_space);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member n_cs_precedes according
   to the current locale. */
private void
test15()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "n_cs_precedes according to the current locale.";

  DBUG_ENTER ("test15");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->n_cs_precedes == def_n_cs_precedes)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member n_cs_precedes is not correct.");
      DBUG_PRINTF ("test15", "n_cs_precedes: %d", lconv_p->n_cs_precedes);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member n_sep_by_space according
   to the current locale. */
private void
test16()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "n_sep_by_space according to the current locale.";

  DBUG_ENTER ("test16");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->n_sep_by_space == def_n_sep_by_space)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member n_sep_by_space is not correct.");
      DBUG_PRINTF ("test16", "n_sep_by_space: %d", lconv_p->n_sep_by_space);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member p_sign_posn according
   to the current locale. */
private void
test17()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "p_sign_posn according to the current locale.";

  DBUG_ENTER ("test17");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->p_sign_posn == def_p_sign_posn)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member p_sign_posn is not correct.");
      DBUG_PRINTF ("test17", "p_sign_posn: %d", lconv_p->p_sign_posn);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function sets the struct lconv member n_sign_posn according
   to the current locale. */
private void
test18()
{
  struct lconv *lconv_p;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify this function sets the struct lconv member "
	       "n_sign_posn according to the current locale.";

  DBUG_ENTER ("test18");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  lconv_p = localeconv();

  if (lconv_p->n_sign_posn == def_n_sign_posn)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The lconv's member n_sign_posn is not correct.");
      DBUG_PRINTF ("test18", "n_sign_posn: %d", lconv_p->n_sign_posn);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
