/*
 * LI18NUX2K.L1/base/mblen/mblen.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <locale.h>
#include <wchar.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();

/* LATIN SMALL LETTER A */
private unsigned char *correct_chara1 = "A";
private wchar_t	      correct_wchara1 = L'A';
private size_t	      correct_ret1    = 1;

/* LATIN SMALL LETTER A WITH DIAERESIS */
private unsigned char correct_chara2[] = {0xC3, 0xA4, 0x61, 0x00};
private wchar_t	      correct_wchara2  = 0x00E4;
private size_t	      correct_ret2     = 2;

/* HIRAGANA LETTER A */
private unsigned char correct_chara3[] = {0xE3, 0x81, 0x82, 0x61, 0x00};
private wchar_t	      correct_wchar3   = 0x3042;
private size_t	      correct_ret3     = 3;

/* In correct character */
private unsigned char incorrect_chara[] = {0xE3, 0x81, 0x00};


#define NO_TESTS 4
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	NULL, 0
};


/* When s is not NULL and the byte sequence starting at s shows null character,
   verify this function returns 0. */
private void
test1()
{
  size_t  ret; 
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the byte sequence starting at s "
	       "shows null character, verify this function returns 0.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if (mblen ("", 1) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* When s is not NULL and the byte sequence starting at s contains a complete
   multibyte character, verify this function returns the length of bytes which
   are used to represent the character. */
private void
test2()
{
  size_t  ret, n = 6;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the byte sequence starting at s "
	       "contains a complete multibyte character, verify this function "
	       "returns the length of bytes which are used to represent the "
	       "character.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if (mblen(correct_chara1, n) == correct_ret1)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }
  
  if (mblen(correct_chara2, n) == correct_ret2)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  if (mblen(correct_chara3, n) == correct_ret3)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* When s is not NULL and the byte sequence starting at s does not contain a
   complete multibyte character, verify this function returns -1. */
private void
test3()
{
  size_t  ret; 
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the byte sequence starting at s does "
	       "not contain a complete multibyte character, verify this "
	       "function returns -1.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if (mblen (incorrect_chara, 4) == -1)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* When s is NULL, verify this function returns 0. (Strictly speaking, when
   s is NULL, this function should return 0 if the encode is stateless, or
   should return 1 if the encode has non-trivial shift state. But this time
   we do not test the locale whose encode is non-trivial shift state.) */
private void
test4()
{
  size_t  ret; 
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is NULL, verify this function returns 0. (Strictly "
	       "speaking, when s is NULL, this function should return 0 if "
	       "the encode is stateless, or should return 1 if the encode "
	       "has non-trivial shift state. But this time we do not test "
	       "the locale whose encode is non-trivial shift state.)";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if (mblen (NULL, 1) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
