/*
 * LI18NUX2K.L1/base/mbrtowc/mbrtowc.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <locale.h>
#include <wchar.h>
#include <errno.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();

/* LATIN SMALL LETTER A */
private unsigned char *correct_chara1 = "A";
private wchar_t	      correct_wchara1 = L'A';
private size_t	      correct_ret1    = 1;

/* LATIN SMALL LETTER A WITH DIAERESIS */
private unsigned char correct_chara2[] = {0xC3, 0xA4, 0x61, 0x00};
private wchar_t	      correct_wchara2  = 0x00E4;
private size_t	      correct_ret2     = 2;

/* HIRAGANA LETTER A */
private unsigned char correct_chara3[] = {0xE3, 0x81, 0x82, 0x61, 0x00};
private wchar_t	      correct_wchara3  = 0x3042;
private size_t	      correct_ret3     = 3;

/* In correct character (the byte sequence has invalid bytes.) */
private unsigned char incorrect_chara1[] = {0xE3, 0xE3, 0x00};

/* In correct character (the byte sequence is not complete as a character.) */
private unsigned char incorrect_chara2[] = {0xE3, 0x81, 0x82, 0x00};
private size_t	      inc_byte_size      = 2;

#define NO_TESTS 5
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	test5, 5,
	NULL, 0
};


/* When s is not NULL, and the byte sequence starting at s shows null
   character, verify this function returns 0 and stores null wide character
   at pwc.  */
private void
test1()
{
  size_t  ret; 
  mbstate_t state;
  wchar_t wc;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL, and the byte sequence starting at s "
	       "shows null character, verify this function returns 0 and "
	       "stores null wide character at pwc.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  memset (&state, '\0', sizeof (mbstate_t));
  if (mbrtowc (&wc, "", 1, &state) == 0)
    if (wc == L'\0')
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The wide character stored at pwc is not correct");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* When s is not NULL and the byte sequence starting at s contains a complete
   multibyte character, verify this function returns the length of bytes which
   are used to represent the multibyte character, and stores wide character
   which shows as same character as the multibyte character at pwc. */
private void
test2()
{
  size_t   ret, n = 6;
  mbstate_t state;
  wchar_t wc;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the byte sequence starting at s "
	       "contains a complete multibyte character, verify this function "
	       "returns the length of bytes which are used to represent the "
	       "multibyte character, and stores wide character which shows as "
	       "same character as the multibyte character at pwc.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  memset (&state, '\0', sizeof (mbstate_t));
  if (mbrtowc (&wc, correct_chara1, n, &state) == correct_ret1)
    if (wc == correct_wchara1)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The wide character stored at pwc is not correct");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }
  
  memset (&state, '\0', sizeof (mbstate_t));
  if (mbrtowc (&wc, correct_chara2, n, &state) == correct_ret2)
    if (wc == correct_wchara2)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The wide character stored at pwc is not correct");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  memset (&state, '\0', sizeof (mbstate_t));
  if (mbrtowc (&wc, correct_chara3, n, &state) == correct_ret3)
    if (wc == correct_wchara3)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The wide character stored at pwc is not correct");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* When s is not NULL and the multibyte sequence starting at s contain a
   invalid byte which are used to represent the character, verify this
   function returns -1 and set errno EILSEQ. */
   
private void
test3()
{
  wchar_t wc;
  mbstate_t state;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the multibyte sequence starting at s "
	       "contain a invalid byte which are used to represent the "
	       "character, verify this function returns -1 and set errno "
	       "EILSEQ.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  errno = 0;
  memset (&state, '\0', sizeof (mbstate_t));
  if (mbrtowc (&wc, incorrect_chara1, 4, &state) == -1)
    if (errno == EILSEQ)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The errno value is not correct.");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* When s is not NULL and the multibyte sequence starting at s does not contain
   a complete multibyte character, verify this function returns -2. */
private void
test4()
{
  int ret;
  wchar_t wc;
  mbstate_t state;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When s is not NULL and the multibyte sequence starting at s "
	       "does not contain a complete multibyte character, verify this "
	       "function returns -2.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  memset (&state, '\0', sizeof (mbstate_t));
  if ((ret = mbrtowc (&wc, incorrect_chara2, inc_byte_size, &state)) == -2)
    PATH_TRACE;
  else
    {
      DBUG_PRINTF("test4", "ret = %d", ret);
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* When s is NULL, verify the behavior of this function is equivalent to the
   behavior as mbrtowc(NULL, "", 1, ps). */
   
private void
test5()
{
    size_t  ret;
    mbstate_t state1, state2;
    wchar_t wc;
    char message[64] = "Test Locale is ";
    int  pathok = 0;
    char *desc = "When s is NULL, verify the behavior of this function is "
		 "equivalent to the behavior as mbrtowc(NULL, "", 1, ps).";

    DBUG_ENTER ("test5");
    tet_infoline (desc);

    if (setlocale(LC_ALL, test_locale) == NULL)
      {
	xx_rpt (FAILURE);
	in_rpt ("Cannot use test locale.");
	DBUG_VOID_RETURN;
      }

    strcat (message, test_locale);
    tet_infoline (message);

    globok = 1;

    memset (&state1, '\0', sizeof (mbstate_t));
    state2 = state1;
    if (mbrtowc (&wc, NULL, 1, &state1) == mbrtowc (&wc, "", 1, &state2))
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The return value is not correct.");
      }

    PATH_XS_RPT(1);
    DBUG_VOID_RETURN;
}

