/*
 * LI18NUX2K.L1/base/nl_langinfo/nl_langinfo.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <locale.h>
#include <nl_types.h>
#include <langinfo.h>

private char *test_locale = "LTP_1.UTF-8";

private nl_item item[] = {
#ifdef CODESET
      CODESET,
#endif
#ifdef D_T_FMT
      D_T_FMT,
#endif
#ifdef D_FMT
      D_FMT,
#endif
#ifdef T_FMT
      T_FMT,
#endif
#ifdef T_FMT_AMPM
      T_FMT_AMPM,
#endif
#ifdef AM_STR
      AM_STR,
#endif
#ifdef PM_STR
      PM_STR,
#endif
#ifdef DAY_1
      DAY_1,
#endif
#ifdef DAY_2
      DAY_2,
#endif
#ifdef DAY_3
      DAY_3,
#endif
#ifdef DAY_4
      DAY_4,
#endif
#ifdef DAY_5
      DAY_5,
#endif
#ifdef DAY_6
      DAY_6,
#endif
#ifdef DAY_7
      DAY_7,
#endif
#ifdef ABDAY_1
      ABDAY_1,
#endif
#ifdef ABDAY_2
      ABDAY_2,
#endif
#ifdef ABDAY_3
      ABDAY_3,
#endif
#ifdef ABDAY_4
      ABDAY_4,
#endif
#ifdef ABDAY_5
      ABDAY_5,
#endif
#ifdef ABDAY_6
      ABDAY_6,
#endif
#ifdef ABDAY_7
      ABDAY_7,
#endif
#ifdef MON_1
      MON_1,
#endif
#ifdef MON_2
      MON_2,
#endif
#ifdef MON_3
      MON_3,
#endif
#ifdef MON_4
      MON_4,
#endif
#ifdef MON_5
      MON_5,
#endif
#ifdef MON_6
      MON_6,
#endif
#ifdef MON_7
      MON_7,
#endif
#ifdef MON_8
      MON_8,
#endif
#ifdef MON_9
      MON_9,
#endif
#ifdef MON_10
      MON_10,
#endif
#ifdef MON_11
      MON_11,
#endif
#ifdef MON_12
      MON_12,
#endif
#ifdef ABMON_1
      ABMON_1,
#endif
#ifdef ABMON_2
      ABMON_2,
#endif
#ifdef ABMON_3
      ABMON_3,
#endif
#ifdef ABMON_4
      ABMON_4,
#endif
#ifdef ABMON_5
      ABMON_5,
#endif
#ifdef ABMON_6
      ABMON_6,
#endif
#ifdef ABMON_7
      ABMON_7,
#endif
#ifdef ABMON_8
      ABMON_8,
#endif
#ifdef ABMON_9
      ABMON_9,
#endif
#ifdef ABMON_10
      ABMON_10,
#endif
#ifdef ABMON_11
      ABMON_11,
#endif
#ifdef ABMON_12
      ABMON_12,
#endif
#ifdef ERA
      ERA,
#endif
#ifdef ERA_D_FMT
      ERA_D_FMT,
#endif
#ifdef ERA_D_T_FMT
      ERA_D_T_FMT,
#endif
#ifdef ERA_T_FMT
      ERA_T_FMT,
#endif
#ifdef ALT_DIGITS
      ALT_DIGITS,
#endif
#ifdef RADIXCHAR
      RADIXCHAR,
#endif
#ifdef THOUSEP
      THOUSEP,
#endif
#ifdef YESSTR
      YESSTR,
#endif
#ifdef NOSTR
      NOSTR,
#endif
#ifdef YESEXPR
      YESEXPR,
#endif
#ifdef NOEXPR
      NOEXPR,
#endif
#ifdef CRNCYSTR
      CRNCYSTR
#endif
};

private char *codeset	  = "UTF-8";
private char *d_t_fmt	  = "%Yめ%m¯%dÀ %Hs%MÍ%Sğ";
private char *d_fmt	  = "%Y%m¯%dÀ";
private char *t_fmt	  = "%Hs%MÍゑ%S";
private char *t_fmt_ampm  = "%p%IĞ%M∽%Sプ";
private char *am_str	  = "£前";
private char *pm_str	  = "ちG";
private char *day_1	  = "±";
private char *day_2	  = "朒}愁";
private char *day_3	  = "†џ";
private char *day_4	  = "E™";
private char *day_5	  = "p";
private char *day_6	  = "⇒∨B";
private char *day_7	  = "あ";
private char *abday_1	  = "←";
private char *abday_2	  = "┏┓";
private char *abday_3	  = "↑";
private char *abday_4	  = "スギ";
private char *abday_5	  = "↓";
private char *abday_6	  = "!";
private char *abday_7	  = "⇒";
private char *mon_1	  = "睦a";
private char *mon_2	  = "如a";
private char *mon_3	  = "弥生";
private char *mon_4	  = "卯a";
private char *mon_5	  = "皐";
private char *mon_6	  = "水無a";
private char *mon_7	  = "文a";
private char *mon_8	  = "葉a";
private char *mon_9	  = "長";
private char *mon_10	  = "神無a";
private char *mon_11	  = "霜a";
private char *mon_12	  = "師走";
private char *abmon_1	  = "!";
private char *abmon_2	  = "♯万";
private char *abmon_3	  = "∫1月";
private char *abmon_4	  = "。";
private char *abmon_5	  = "いぃ";
private char *abmon_6	  = "W";
private char *abmon_7	  = "⇔";
private char *abmon_8	  = "乏丼β";
private char *abmon_9	  = "∬J";
private char *abmon_10	  = "@Ǖ";
private char *abmon_11	  = "々・";
private char *abmon_12	  = "□7♀";
private char *era_d_fmt   = "%EY%mΑ%dΛ";
private char *era_d_t_fmt = "%EY%ms%dケ %Hァ%M分%S信";
private char *era_t_fmt   = "%p%Iœ%MP%S〒";
private char *radixchar   = "*";
private char *thousep	  = "|";
private char *yesexpr	  = "^([■□☆○]|♭┼|◎╂)";
private char *noexpr	  = "^([┰♪ぁO]|┼┼え|╂╂W)";
private char *yesstr	  = "♬┼♂";
private char *nostr	  = "Áい";
private char *crncystr    = "-♪";

private char *era[] = {
    "+:1:1989/01/08:+*:ヅn:%EC%Ey¿",
    "+:1:1926/12/25:1989/01/07:ß×:%EC%EyΔ",
    "+:1:1912/07/30:1926/12/24:MΕ:%EC%Ey΅",
    "+:6:1873/01/01:1912/07/29:※џ:%EC%Ey℃",
    "+:1:0001/01/01:1872/12/31:俵太:%EC%Eyづ",
    "+:1:-0001/12/31:-*:俺e©:%EC%EyΔ" 
};

private char *alt_digits[] = {
    "À", "9", "Ė", "は", "z", "┻", "ф", "H", "я", "俋",
    "‖", "‖9", "‖Ė", "‖は", "‖z",
       "‖┻", "‖ф", "‖H", "‖я", "‖俋",
     "Ė‖", "Ė‖9", "Ė‖Ė", "Ė‖は", "Ė‖z",
       "Ė‖┻", "Ė‖ф", "Ė‖H", "Ė‖я", "Ė‖俋",
    "は‖", "は‖9", "は‖Ė", "は‖は", "は‖z",
       "は‖┻", "は‖ф", "は‖H", "は‖я", "は‖俋",
    "z‖", "z‖9", "z‖Ė", "z‖は", "z‖z",
      "z‖┻", "z‖ф", "z‖H", "z‖я", "z‖俋",
    "┻‖", "┻‖9", "┻‖Ė", "┻‖は", "┻‖z",
       "┻‖┻", "┻‖ф", "┻‖H", "┻‖я", "┻‖俋",
    "ф‖", "ф‖9", "ф‖Ė", "ф‖は", "ф‖z",
       "ф‖┻", "ф‖ф", "ф‖H", "ф‖я", "ф‖俋",
    "H‖", "H‖9", "H‖Ė", "H‖は", "H‖z",
       "H‖┻", "H‖ф", "H‖H", "H‖я", "H‖俋",
    "я‖", "я‖9", "я‖Ė", "я‖は", "я‖z",
       "я‖┻", "я‖ф", "я‖H", "я‖я", "я‖俋",
    "俋‖", "俋‖9", "俋‖Ė", "俋‖は", "俋‖z",
        "俋‖┻", "俋‖ф", "俋‖H", "俋‖я", "俋‖俋"
};


private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();
private void test7();
private void test8();
private void test9();
private void test10();
private void test11();
private void test12();
private void test13();
private void test14();
private void test15();
private void test16();
private void test17();
private void test18();
private void test19();
private void test20();
private void test21();
private void test22();
private void test23();
private void test24();
private void test25();
private void test26();
private void test27();
private void test28();
private void test29();
private void test30();
private void test31();
private void test32();
private void test33();
private void test34();
private void test35();
private void test36();
private void test37();
private void test38();
private void test39();
private void test40();
private void test41();
private void test42();
private void test43();
private void test44();
private void test45();
private void test46();
private void test47();
private void test48();
private void test49();
private void test50();
private void test51();
private void test52();
private void test53();
private void test54();
private void test55();
private void test56();
private void test57();
private void test58();
private void test59();

#define NO_TESTS 59
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,   1,
	test2,   2,
	test3,   3,
	test4,   4,
	test5,   5,
	test6,   6,
	test7,   7,
	test8,   8,
	test9,   9,
	test10, 10,
	test11, 11,
	test12, 12,
	test13, 13,
	test14, 14,
	test15, 15,
	test16, 16,
	test17, 17,
	test18, 18,
	test19, 19,
	test20, 20,
	test21, 21,
	test22, 22,
	test23, 23,
	test24, 24,
	test25, 25,
	test26, 26,
	test27, 27,
	test28, 28,
	test29, 29,
	test30, 30,
	test31, 31,
	test32, 32,
	test33, 33,
	test34, 34,
	test35, 35,
	test36, 36,
	test37, 37,
	test38, 38,
	test39, 39,
	test40, 40,
	test41, 41,
	test42, 42,
	test43, 43,
	test44, 44,
	test45, 45,
	test46, 46,
	test47, 47,
	test48, 48,
	test49, 49,
	test50, 50,
	test51, 51,
	test52, 52,
	test53, 53,
	test54, 54,
	test55, 55,
	test56, 56,
	test57, 57,
	test58, 58,
	test59, 59,
	NULL, 0
};


/* If item is CODESET, verify this function returns a pointer to a string
   which shows codeset name. */
private void
test1()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is CODESET, verify this function returns a pointer "
	       "to a string which shows codeset name.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef CODESET
  xx_rpt (FAILURE);
  in_rpt ("`CODESET' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(CODESET);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, codeset) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is D_T_FMT, verify this function returns a pointer to a string
   which shows formatting date and time. */
private void
test2()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is D_T_FMT, verify this function returns a pointer to "
	       "a string which shows formatting date and time.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef D_T_FMT
  xx_rpt (FAILURE);
  in_rpt ("`D_T_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(D_T_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, d_t_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is D_FMT, verify this function returns a pointer to a string which
   shows a date format string. */
private void
test3()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is D_FMT, verify this function returns a pointer to "
	       "a string which shows a date format string.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef D_FMT
  xx_rpt (FAILURE);
  in_rpt ("`D_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(D_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, d_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is T_FMT, verify this function returns a pointer to a string which
   shows time format string. */
private void
test4()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is T_FMT, verify this function returns a pointer to "
	       "a string which shows time format string.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef T_FMT
  xx_rpt (FAILURE);
  in_rpt ("`T_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(T_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, t_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is T_FMT_AMPM, verify this function returns a pointer to a string
   which shows a.m. or p.m. time format string. */ 
private void
test5()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is T_FMT_AMPM, verify this function returns a pointer "
	       "to a string which shows a.m. or p.m. time format string.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef T_FMT_AMPM
  xx_rpt (FAILURE);
  in_rpt ("`T_FMT_AMPM' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(T_FMT_AMPM);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, t_fmt_ampm) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is AM_STR, verify this function returns a pointer to a string which
   shows Ante Meridian affix. */
private void
test6()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is AM_STR, verify this function returns a pointer to "
	       "a string which shows Ante Meridian affix.";

  DBUG_ENTER ("test6");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef AM_STR
  xx_rpt (FAILURE);
  in_rpt ("`AM_STR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(AM_STR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, am_str) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is PM_STR, verify this function returns a pointer to a string which
   shows Post Meridian affix. */
private void
test7()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is PM_STR, verify this function returns a pointer to "
	       "a string which shows Post Meridian affix.";

  DBUG_ENTER ("test7");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef PM_STR
  xx_rpt (FAILURE);
  in_rpt ("`PM_STR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(PM_STR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, pm_str) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_1, verify this function returns a pointer to a string which
   shows name of the first day of the week. */ 
private void
test8()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_1, verify this function returns a pointer to "
	       "a string which shows name of the first day of the week.";

  DBUG_ENTER ("test8");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_1
  xx_rpt (FAILURE);
  in_rpt ("`DAY_1' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_1);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_1) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_2, verify this function returns a pointer to a string which
   shows name of the second day of the week. */ 
private void
test9()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_2, verify this function returns a pointer to "
	       "a string which shows name of the second day of the week.";

  DBUG_ENTER ("test9");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_2
  xx_rpt (FAILURE);
  in_rpt ("`DAY_2' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_2);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_2) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_3, verify this function returns a pointer to a string which
   shows name of the third day of the week. */ 
private void
test10()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_3, verify this function returns a pointer to "
	       "a string which shows name of the third day of the week.";

  DBUG_ENTER ("test10");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_3
  xx_rpt (FAILURE);
  in_rpt ("`DAY_3' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_3);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_3) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_4, verify this function returns a pointer to a string which
   shows name of the fourth day of the week. */ 
private void
test11()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_4, verify this function returns a pointer to "
	       "a string which shows name of the fourth day of the week.";

  DBUG_ENTER ("test11");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_4
  xx_rpt (FAILURE);
  in_rpt ("`DAY_4' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_4);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_4) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_5, verify this function returns a pointer to a string which
   shows name of the fifth day of the week. */ 
private void
test12()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_5, verify this function returns a pointer to "
	       "a string which shows name of the fifth day of the week.";

  DBUG_ENTER ("test12");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_5
  xx_rpt (FAILURE);
  in_rpt ("`DAY_5' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_5);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_5) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_6, verify this function returns a pointer to a string which
   shows name of the sixth day of the week. */ 
private void
test13()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_6, verify this function returns a pointer to "
	       "a string which shows name of the sixth day of the week.";

  DBUG_ENTER ("test13");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_6
  xx_rpt (FAILURE);
  in_rpt ("`DAY_6' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_6);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_6) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is DAY_7, verify this function returns a pointer to a string which
   shows name of the seventh day of the week. */ 
private void
test14()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is DAY_7, verify this function returns a pointer to "
	       "a string which shows name of the seventh day of the week.";

  DBUG_ENTER ("test14");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef DAY_7
  xx_rpt (FAILURE);
  in_rpt ("`DAY_7' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(DAY_7);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, day_7) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_1, verify this function returns a pointer to a string
   which shows abbreviated name of the first day of the week. */
private void
test15()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_1, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the first day of "
	       "the week.";

  DBUG_ENTER ("test15");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_1
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_1' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_1);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_1) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_2, verify this function returns a pointer to a string
   which shows abbreviated name of the second day of the week. */
private void
test16()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_2, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the second day of "
	       "the week.";

  DBUG_ENTER ("test16");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_2
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_2' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_2);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_2) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_3, verify this function returns a pointer to a string
   which shows abbreviated name of the third day of the week. */
private void
test17()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_3, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the third day of "
	       "the week.";

  DBUG_ENTER ("test17");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_3
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_3' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_3);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_3) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_4, verify this function returns a pointer to a string
   which shows abbreviated name of the fourth day of the week. */
private void
test18()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_4, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the fourth day of "
	       "the week.";

  DBUG_ENTER ("test18");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_4
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_4' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_4);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_4) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_5, verify this function returns a pointer to a string
   which shows abbreviated name of the fifth day of the week. */
private void
test19()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_5, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the fifth day of "
	       "the week.";

  DBUG_ENTER ("test19");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_5
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_5' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_5);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_5) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_6, verify this function returns a pointer to a string
   which shows abbreviated name of the sixth day of the week. */
private void
test20()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_6, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the sixth day of "
	       "the week.";

  DBUG_ENTER ("test20");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_6
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_6' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_6);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_6) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABDAY_7, verify this function returns a pointer to a string
   which shows abbreviated name of the seventh day of the week. */
private void
test21()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABDAY_7, verify this function returns a pointer "
	       "to a string which shows abbreviated name of the seventh day of "
	       "the week.";

  DBUG_ENTER ("test21");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABDAY_7
  xx_rpt (FAILURE);
  in_rpt ("`ABDAY_7' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABDAY_7);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abday_7) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_1, verify this function returns a pointer to a string which
   shows a string which shows name of the first month of the year. */
private void
test22()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_1, verify this function returns a pointer to "
	       "a string which shows a string which shows name of the first "
	       "month of the year.";

  DBUG_ENTER ("test22");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_1
  xx_rpt (FAILURE);
  in_rpt ("`MON_1' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_1);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_1) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_2, verify this function returns a pointer to a string
   which shows a name of the second month. */
private void
test23()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_2, verify this function returns a pointer to "
	       "a string which shows a name of the second month.";

  DBUG_ENTER ("test23");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_2
  xx_rpt (FAILURE);
  in_rpt ("`MON_2' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_2);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_2) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_3, verify this function returns a pointer to a string
   which shows a name of the third month. */
private void
test24()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_3, verify this function returns a pointer to "
	       "a string which shows a name of the third month.";

  DBUG_ENTER ("test24");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_3
  xx_rpt (FAILURE);
  in_rpt ("`MON_3' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_3);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_3) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_4, verify this function returns a pointer to a string
   which shows a name of the fourth month. */
private void
test25()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_4, verify this function returns a pointer to "
	       "a string which shows a name of the fourth month.";

  DBUG_ENTER ("test25");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_4
  xx_rpt (FAILURE);
  in_rpt ("`MON_4' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_4);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_4) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_5, verify this function returns a pointer to a string
   which shows a name of the fifth month. */
private void
test26()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_5, verify this function returns a pointer to "
	       "a string which shows a name of the fifth month.";

  DBUG_ENTER ("test26");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_5
  xx_rpt (FAILURE);
  in_rpt ("`MON_5' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_5);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_5) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_6, verify this function returns a pointer to a string
   which shows a name of the sixth month. */
private void
test27()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_6, verify this function returns a pointer to "
	       "a string which shows a name of the sixth month.";

  DBUG_ENTER ("test27");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_6
  xx_rpt (FAILURE);
  in_rpt ("`MON_6' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_6);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_6) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_7, verify this function returns a pointer to a string
   which shows a name of the seventh month. */
private void
test28()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_7, verify this function returns a pointer to "
	       "a string which shows a name of the seventh month.";

  DBUG_ENTER ("test28");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_7
  xx_rpt (FAILURE);
  in_rpt ("`MON_7' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_7);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_7) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_8, verify this function returns a pointer to a string
   which shows a name of the eighth month. */
private void
test29()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_8, verify this function returns a pointer to "
	       "a string which shows a name of the eighth month.";

  DBUG_ENTER ("test29");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_8
  xx_rpt (FAILURE);
  in_rpt ("`MON_8' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_8);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_8) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_9, verify this function returns a pointer to a string
   which shows a name of the ninth month. */
private void
test30()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_9, verify this function returns a pointer to "
	       "a string which shows a name of the ninth month.";

  DBUG_ENTER ("test30");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_9
  xx_rpt (FAILURE);
  in_rpt ("`MON_9' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_9);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_9) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_10, verify this function returns a pointer to a string
   which shows a name of the tenth month. */
private void
test31()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_10, verify this function returns a pointer to "
	       "a string which shows a name of the tenth month.";

  DBUG_ENTER ("test31");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_10
  xx_rpt (FAILURE);
  in_rpt ("`MON_10' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_10);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_10) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_11, verify this function returns a pointer to a string
   which shows a name of the eleventh month. */
private void
test32()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_11, verify this function returns a pointer to "
	       "a string which shows a name of the eleventh month.";

  DBUG_ENTER ("test32");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_11
  xx_rpt (FAILURE);
  in_rpt ("`MON_11' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_11);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_11) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is MON_12, verify this function returns a pointer to a string
   which shows a name of the twelfth month. */
private void
test33()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is MON_12, verify this function returns a pointer to "
	       "a string which shows a name of the twelfth month.";

  DBUG_ENTER ("test33");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef MON_12
  xx_rpt (FAILURE);
  in_rpt ("`MON_12' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(MON_12);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, mon_12) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_1, verify this function returns a pointer to a string
   which shows a abbreviated name of the first month. */
private void
test34()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_1, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the first "
	       "month.";

  DBUG_ENTER ("test34");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_1
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_1' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_1);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_1) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_2, verify this function returns a pointer to a string
   which shows a abbreviated name of the second month. */
private void
test35()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_2, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the second "
	       "month.";

  DBUG_ENTER ("test35");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_2
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_2' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_2);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_2) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_3, verify this function returns a pointer to a string
   which shows a abbreviated name of the third month. */
private void
test36()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_3, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the third "
	       "month.";

  DBUG_ENTER ("test36");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_3
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_3' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_3);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_3) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_4, verify this function returns a pointer to a string
   which shows a abbreviated name of the fourth month. */
private void
test37()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_4, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the fourth "
	       "month.";

  DBUG_ENTER ("test37");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_4
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_4' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_4);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_4) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_5, verify this function returns a pointer to a string
   which shows a abbreviated name of the fifth month. */
private void
test38()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_5, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the fifth "
	       "month.";
  
  DBUG_ENTER ("test38");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_5
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_5' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_5);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_5) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_6, verify this function returns a pointer to a string
   which shows a abbreviated name of the sixth month. */
private void
test39()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_6, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the sixth "
	       "month.";

  DBUG_ENTER ("test39");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_6
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_6' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_6);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_6) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_7, verify this function returns a pointer to a string
   which shows a abbreviated name of the seventh month. */
private void
test40()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_7, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the seventh "
	       "month.";

  DBUG_ENTER ("test40");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_7
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_7' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_7);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_7) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_8, verify this function returns a pointer to a string
   which shows a abbreviated name of the eighth month. */
private void
test41()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_8, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the eighth "
	       "month.";

  DBUG_ENTER ("test41");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_8
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_8' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_8);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_8) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_9, verify this function returns a pointer to a string
   which shows a abbreviated name of the ninth month. */
private void
test42()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_9, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the ninth "
	       "month.";

  DBUG_ENTER ("test42");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_9
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_9' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_9);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_9) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_10, verify this function returns a pointer to a string
   which shows a abbreviated name of the tenth month. */
private void
test43()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_10, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the tenth "
	       "month.";

  DBUG_ENTER ("test43");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_10
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_10' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_10);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_10) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_11, verify this function returns a pointer to a string
   which shows a abbreviated name of the eleventh month. */
private void
test44()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_11, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the eleventh "
	       "month.";

  DBUG_ENTER ("test44");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_11
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_11' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_11);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_11) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ABMON_12, verify this function returns a pointer to a string
   which shows a abbreviated name of the twelfth month. */
private void
test45()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ABMON_12, verify this function returns a pointer "
	       "to a string which shows a abbreviated name of the twelfth "
	       "month.";

  DBUG_ENTER ("test45");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ABMON_12
  xx_rpt (FAILURE);
  in_rpt ("`ABMON_12' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ABMON_12);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, abmon_12) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ERA, verify this function returns a pointer to a string which
   shows a era description segments. */
private void
test46()
{
  size_t i, elenum;
  char *ret, *p;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ERA, verify this function returns a pointer to a "
	       "string which shows a era description segments.";

  DBUG_ENTER ("test46");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  elenum = sizeof(era) / sizeof(era[0]);
  DBUG_PRINTF ("test46", "The number of ERA elements: %d", elenum);

#ifndef ERA
  xx_rpt (FAILURE);
  in_rpt ("`ERA' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ERA);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      for (p = ret, i = 0; i < elenum; p += strlen(p) + 1, i++)
	{
	  if (strcmp (p, era[i]) == 0)
	    {
	      PATH_TRACE;
	    }
	  else
	    {
	      xx_rpt (FAILURE);
	      in_rpt ("Some elements are not correct.");
	      DBUG_PRINTF ("output : %s", p);
	      DBUG_PRINTF ("correct: %s", era[i]);
	      break;
	    }
	}

    }
#endif

  PATH_XS_RPT(2 + elenum);
  DBUG_VOID_RETURN;
}


/* If item is ERA_D_FMT, verify this function returns a pointer to a string
   which shows a era date format string. */
private void
test47()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ERA_D_FMT, verify this function returns a pointer "
	       "to a string which shows a era date format string.";

  DBUG_ENTER ("test47");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ERA_D_FMT
  xx_rpt (FAILURE);
  in_rpt ("`ERA_D_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ERA_D_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, era_d_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ERA_D_T_FMT, verify this function returns a pointer to a string
   which shows a era date and time format string. */
private void
test48()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ERA_D_T_FMT, verify this function returns a "
	       "pointer to a string which shows a era date and time format "
	       "string.";

  DBUG_ENTER ("test48");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ERA_D_T_FMT
  xx_rpt (FAILURE);
  in_rpt ("`ERA_D_T_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ERA_D_T_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, era_d_t_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ERA_T_FMT, verify this function returns a pointer to a string
   which shows a era time format string. */
private void
test49()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ERA_T_FMT, verify this function returns a pointer "
	       "to a string which shows a era time format string.";

  DBUG_ENTER ("test49");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef ERA_T_FMT
  xx_rpt (FAILURE);
  in_rpt ("`ERA_T_FMT' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ERA_T_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, era_t_fmt) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is ALT_DIGITS, verify this function returns a pointer to a string
   which shows a alternative symbols for digits. */
private void
test50()
{
  size_t i, elenum;
  char *ret, *p;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is ALT_DIGITS, verify this function returns a pointer "
	       "to a string which shows a alternative symbols for digits.";

  DBUG_ENTER ("test50");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  elenum = sizeof(alt_digits) / sizeof(alt_digits[0]);
  DBUG_PRINTF ("test50", "The number of ALT_DIGITS elements: %d", elenum);

#ifndef ALT_DIGITS
  xx_rpt (FAILURE);
  in_rpt ("`ALT_DIGITS' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(ALT_DIGITS);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      for (p = ret, i = 0; i < elenum; p += strlen(p) + 1, i++)
	{
	  if (strcmp (p, alt_digits[i]) == 0)
	    {
	      PATH_TRACE;
	    }
	  else
	    {
	      xx_rpt (FAILURE);
	      in_rpt ("Some elements are not correct.");
	      DBUG_PRINTF ("output : %s", p);
	      DBUG_PRINTF ("correct: %s", alt_digits[i]);
	      break;
	    }
	}

    }
#endif

  PATH_XS_RPT(2 + elenum);
  DBUG_VOID_RETURN;
}


/* If item is RADIXCHAR, verify this function returns a pointer to a string
   which shows a radix character. */
private void
test51()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is RADIXCHAR, verify this function returns a pointer "
	       "to a string which shows a radix character.";

  DBUG_ENTER ("test51");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef RADIXCHAR
  xx_rpt (FAILURE);
  in_rpt ("`RADIXCHAR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(RADIXCHAR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, radixchar) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is THOUSEP, verify this function returns a pointer to a string
   which shows a separator for thousands. */
private void
test52()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is THOUSEP, verify this function returns a pointer "
	       "to a string which shows a separator for thousands.";

  DBUG_ENTER ("test52");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef THOUSEP
  xx_rpt (FAILURE);
  in_rpt ("`THOUSEP' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(THOUSEP);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, thousep) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is YESEXPR, verify this function returns a pointer to a string
   which shows a affirmative response expression. */
private void
test53()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is YESEXPR, verify this function returns a pointer "
	       "to a string which shows a affirmative response expression.";

  DBUG_ENTER ("test53");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef YESEXPR
  xx_rpt (FAILURE);
  in_rpt ("`YESEXPR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(YESEXPR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, yesexpr) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is NOEXPR, verify this function returns a pointer to a string
   which shows a negative response expression. */
private void
test54()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is NOEXPR, verify this function returns a pointer "
	       "to a string which shows a negative response expression.";

  DBUG_ENTER ("test54");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef NOEXPR
  xx_rpt (FAILURE);
  in_rpt ("`NOEXPR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(NOEXPR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, noexpr) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is YESSTR, verify this function returns a pointer to a string
   which shows a affirmative response for yes/no queries. */
private void
test55()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is YESSTR, verify this function returns a pointer "
	       "to a string which shows a affirmative response for yes/no "
	       "queries.";

  DBUG_ENTER ("test55");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef YESSTR
  xx_rpt (FAILURE);
  in_rpt ("`YESSTR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(YESSTR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, yesstr) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is NOSTR, verify this function returns a pointer to a string
   which shows a negative response for yes/no queries. */
private void
test56()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is NOSTR, verify this function returns a pointer "
	       "to a string which shows a negative response for yes/no "
	       "queries.";

  DBUG_ENTER ("test56");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef NOSTR
  xx_rpt (FAILURE);
  in_rpt ("`NOSTR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(NOSTR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, nostr) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If item is CRNCYSTR, verify this function returns a pointer to a string
   which shows a currency symbol, preceded by - if the symbol should appear
   before the value, + if the symbol should appear after the value, or . if
   the symbol should replace the radix character. */
private void
test57()
{
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If item is CRNCYSTR, verify this function returns a pointer "
	       "to a string which shows a currency symbol, preceded by - if "
	       "the symbol should appear before the value, + if the symbol "
	       "should appear after the value, or . if the symbol should "
	       "replace the radix character.";

  DBUG_ENTER ("test57");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

#ifndef CRNCYSTR
  xx_rpt (FAILURE);
  in_rpt ("`CRNCYSTR' is not defined at langinfo.h.");
#else
  PATH_TRACE;

  ret = nl_langinfo(CRNCYSTR);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, crncystr) == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }
#endif

  PATH_XS_RPT(3);
  DBUG_VOID_RETURN;
}


/* If the langinfo data is not defined on the current locale, verify this
   function returns a pointer to the corresponding string in the POSIX locale
   against each item. */
private void
test58()
{
  size_t i;
  size_t item_total_num;
  char posix[BUFSIZ];
  char ltp_il1[BUFSIZ];
  char *ret;
  char str[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the langinfo data is not defined on the current locale, "
	       "verify this function returns a pointer to the corresponding "
	       "string in the POSIX locale against each item.";

  DBUG_ENTER ("test58");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  /* Investigating the total number of items. */
  item_total_num = sizeof (item) / sizeof (item[0]);

  for (i = 0; i < item_total_num; i++)
    {
      if (item[i] == CODESET)
	{
	  PATH_TRACE;
	  continue;
	}
      
      /* The ERA comparison will not work since the ERA information has no
         fixed format and in most implementations it will be in non-string
         form, so we do not test the item. */
      if (item[i] == ERA)
	{
	  PATH_TRACE;
	  continue;
	}


      setlocale (LC_ALL, "POSIX");
      if (nl_langinfo (item[i]) == NULL)
	{
	  setlocale (LC_ALL, "LTP_IL1.UTF-8");
	  if (nl_langinfo (item[i]) == NULL)
	    PATH_TRACE;
	  continue;
	}

      setlocale (LC_ALL, "POSIX");
      strcpy (posix, nl_langinfo (item[i]));
      setlocale (LC_ALL, "LTP_IL1.UTF-8");
      strcpy (ltp_il1, nl_langinfo (item[i]));

      if (strcmp (posix, ltp_il1) == 0)
	PATH_TRACE;
      else
	{
	  DBUG_PRINTF ("test58", "The %dth item is wrong.", i);
	  DBUG_PRINTF ("test58", " POSIX: %s", posix);
	  DBUG_PRINTF ("test58", " LTPIL: %s", ltp_il1);
	}
    }

  if (pathok < item_total_num)
    {
      xx_rpt (FAILURE);
      in_rpt ("Some items are incorrect.");
    }

  PATH_XS_RPT (item_total_num);
  DBUG_VOID_RETURN;
}

/* Verify this function returns a pointer to an empty string if item contains
   an invalid setting. */ 
private void
test59()
{
  char *ret;
  char str[BUFSIZ];
  int  pathok = 0;
  char *desc = "Verify this function returns a pointer to an empty string if "
	       "item contains an invalid setting.";

  DBUG_ENTER ("test59");
  tet_infoline (desc);

  if (setlocale(LC_ALL, "LTP_IL2.UTF-8") == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use LTP_IL2.UTF-8 locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  /* LTP_IL2 includes a bug at d_fmt belongs to LC_TIME. */
  ret = nl_langinfo(D_FMT);

  if (ret == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("NULL is returned.");
    }
  else
    {
      PATH_TRACE;
      if (strcmp (ret, "") == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The return value is not correct.");
	  DBUG_PRINTF ("Return Value: %s", ret);
	}
    }

  PATH_XS_RPT(2);
  DBUG_VOID_RETURN;
}
