/*
 * LI18NUX2K.L1/base/strptime/strptime.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <locale.h>

private char *test_locale = "LTP_1.UTF-8";

struct tm ans_time = 
{
    12,	  /* seconds */
    30,	  /* minutes */
    16,	  /* hours */
    21,	  /* day of the month */
     4,	  /* month */
   101,	  /* year */
     1,	  /* day of the week */
   140,	  /* day in the year */
     0    /* daylight saving time */
};

private char *def_abwday          = "┏┓";
private char *def_fullwday        = "朒}愁";
private char *def_abmonth         = "いぃ";
private char *def_fullmonth       = "皐";
private char *def_d_t_fmt         = "2001め05¯21À 16s30Í12ğ";
private char *def_century         = "20";
private char *def_day             = "21";
private char *def_m_d_y           = "05/21/01";
private char *def_24h	          = "16";
private char *def_12h	          = "04";
private char *def_yday	          = "141";
private char *def_mon_dec         = "05";
private char *def_minutes         = "30";
private char *def_am_pm           = "ちG";
private char *def_am_pm_time	  = "ちG04Ğ30∽12プ";
private char *def_second          = "12";
private char *def_week_dec_s      = "20";
private char *def_day_of_week_dec = "1";
private char *def_week_dec_m      = "21";
private char *def_prefered_date   = "200105¯21À";
private char *def_prefered_time   = "16s30Íゑ12";
private char *def_double_year     = "01";
private char *def_full_year       = "2001";
private char *alt_d_t_fmt	  = "ヅn13¿05s21ケ 16ァ30分12信";
private char *alt_year_name	  = "ヅn";
private int  alt_base_year	  = 89;
private char *alt_date		  = "ヅn13¿05Α21Λ";
private char *alt_time		  = "ちG04œ30P12〒";
private char *alt_year_dec	  = "ヅn13";
private char *alt_year		  = "ヅn13¿";
private char *alt_num_day	  = "Ė‖9";
private char *alt_num_24h     	  = "‖ф";
private char *alt_num_12h 	  = "z";
private char *alt_num_month	  = "┻";
private char *alt_num_minutes	  = "は‖";
private char *alt_num_second	  = "‖Ė";
private char *alt_num_weeknum_s	  = "Ė‖";
private char *alt_num_day_of_week = "9";
private char *alt_num_weeknum_m	  = "Ė‖9";
private char *alt_num_year	  = "9";


private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();
private void test7();
private void test8();
private void test9();
private void test10();
private void test11();
private void test12();
private void test13();
private void test14();
private void test15();
private void test16();
private void test17();
private void test18();
private void test19();
private void test20();
private void test21();
private void test22();
private void test23();
private void test24();
private void test25();
private void test26();
private void test27();
private void test28();
private void test29();
private void test30();
private void test31();
private void test32();
private void test33();
private void test34();
private void test35();
private void test36();
private void test37();
private void test38();
private void test39();
private void test40();
private void test41();
private void test42();
private void test43();
private void test44();

#define NO_TESTS 44
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,   1,
	test2,   2,
	test3,   3,
	test4,   4,
	test5,   5,
	test6,   6,
	test7,   7,
	test8,   8,
	test9,   9,
	test10, 10,
	test11, 11,
	test12, 12,
	test13, 13,
	test14, 14,
	test15, 15,
	test16, 16,
	test17, 17,
	test18, 18,
	test19, 19,
	test20, 20,
	test21, 21,
	test22, 22,
	test23, 23,
	test24, 24,
	test25, 25,
	test26, 26,
	test27, 27,
	test28, 28,
	test29, 29,
	test30, 30,
	test31, 31,
	test32, 32,
	test33, 33,
	test34, 34,
	test35, 35,
	test36, 36,
	test37, 37,
	test38, 38,
	test39, 39,
	test40, 40,
	test41, 41,
	test42, 42,
	test43, 43,
	test44, 44,
	NULL, 0
};


/* Print each member of structure `tm'. (for debugging) */
private void
print_tm(char *testnum, struct tm *obj)
{
  DBUG_PRINTF (testnum, "seconds         : %d", obj->tm_sec);
  DBUG_PRINTF (testnum, "minutes         : %d", obj->tm_min);
  DBUG_PRINTF (testnum, "hours           : %d", obj->tm_hour);
  DBUG_PRINTF (testnum, "day of the month: %d", obj->tm_mday);
  DBUG_PRINTF (testnum, "month           : %d", obj->tm_mon);
  DBUG_PRINTF (testnum, "year            : %d", obj->tm_year);
  DBUG_PRINTF (testnum, "day of the week : %d", obj->tm_wday);
  DBUG_PRINTF (testnum, "day of the year : %d", obj->tm_yday);
  DBUG_PRINTF (testnum, "tm_isdst        : %d", obj->tm_isdst);
}


/* If a directive is an ordinary character (i.e. except for %, and
   whitespace character), verify the next character is read, and compare
   with the directive and the read one and when they are not equivalent,
   the directive fails, and the differing and subsequent characters remain
   unread. */
private void
test1()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%pa%I"};
  char def_hour12_am_pm[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If a directive is an ordinary character (i.e. except for %, "
	       "and whitespace character), verify the next character is "
	       "read, and compare with the directive and the read one and "
	       "when they are not equivalent, the directive fails, and the "
	       "differing and subsequent characters remain unread.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_hour12_am_pm, "%sa%s", def_am_pm, def_12h);
      strptime (def_hour12_am_pm, format[i], &conv_time);
      print_tm ("test1", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The ordinary character is not interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* Verify a series of directives composed of `n', `t', whitespace
   characters or any combination is executed by reading input until no more
   valid input can be read, or up to the first character that is not
   whitespace wide character, and which remains unread. */
private void
test2()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%p \t%I", "%p%n%I", "%p%t%I", "%p%t%n %I"};
  char def_hour12_am_pm[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "Verify a series of directives composed of `n', `t', "
	       "whitespace characters or any combination is executed by "
	       "reading input until no more valid input can be read, or up "
	       "to the first character that is not whitespace wide "
	       "character, and which remains unread.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_hour12_am_pm, "%s   %s", def_am_pm, def_12h);
      strptime (def_hour12_am_pm, format[i], &conv_time);
      print_tm ("test2", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The `%%n', `%%t' or whitespaces are not interpreted "
		  "correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `a' or `A', verify this function converts the
   characters which shows either the abbreviated or full weekday name
   according to the current locale. */
private void
test3()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%a", "%A"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `a' or `A', verify this "
	       "function converts the characters which shows either the "
	       "abbreviated or full weekday name according to the current "
	       "locale.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      /* abbreviated */
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_abwday, format[i], &conv_time);
      print_tm ("test3", &conv_time);
      if (ans_time.tm_wday == conv_time.tm_wday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The abbreviated weekday name is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
      
      /* full */
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_fullwday, format[i], &conv_time);
      print_tm ("test3", &conv_time);
      if (ans_time.tm_wday == conv_time.tm_wday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The full weekday name is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num * 2);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `b', `B' or `h', verify this function
   converts the characters either the abbreviated or full month name according
   to the current locale. */ 
private void
test4()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%b", "%B", "%h"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `b', `B' or `h', verify this "
	       "function converts the characters either the abbreviated or "
	       "full month name according to the current locale.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      /* abbreviated */
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_abmonth, format[i], &conv_time);
      print_tm ("test4", &conv_time);
      if (ans_time.tm_mon == conv_time.tm_mon)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The abbreviated month name is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
      
      /* full */
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_fullmonth, format[i], &conv_time);
      print_tm ("test4", &conv_time);
      if (ans_time.tm_mon == conv_time.tm_mon)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The full month name is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num * 2);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `c', verify this function converts
   the characters which is the locale's appropriate date and time
   representation. */
private void
test5()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%c"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `c', verify this function "
	       "converts the characters which is the locale's appropriate "
	       "date and time representation.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_d_t_fmt, format[i], &conv_time);
      print_tm ("test5", &conv_time);
      if (ans_time.tm_sec  == conv_time.tm_sec  ||
	  ans_time.tm_min  == conv_time.tm_min  ||
	  ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_mday == conv_time.tm_mday ||
	  ans_time.tm_mon  == conv_time.tm_mon  ||
	  ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The date and time is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If conversion character is `C', verify this function converts the
   characters which shows the century number. */
private void
test6()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%C"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If conversion character is `C', verify this function converts "
	       "the characters which shows the century number.";

  DBUG_ENTER ("test6");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_century, format[i], &conv_time);
      print_tm ("test6", &conv_time);
      if ((ans_time.tm_year / 100) == (conv_time.tm_year / 100))
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The century is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `d' or `e', verify this function converts
   the characters which shows the day of month. */
private void
test7()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%d", "%e"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `d' or `e', verify this "
	       "function converts the characters which shows the day of month.";

  DBUG_ENTER ("test7");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_day, format[i], &conv_time);
      print_tm ("test7", &conv_time);
      if (ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The day of the month is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `D', verify this function converts the
   characters which shows the date as same style as `%m'/`%d'/`%y'. */
  private void
test8()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%D"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `D', verify this function "
	       "converts the characters which shows the date as same style "
	       "as `%m'/`%d'/`%y'.";

  DBUG_ENTER ("test8");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_m_d_y, format[i], &conv_time);
      print_tm ("test8", &conv_time);
      if (ans_time.tm_mday == conv_time.tm_mday ||
	  ans_time.tm_mon  == conv_time.tm_mon  ||
	  ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The date is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `H', verify this function converts the
   characters which shows the hour(24-hour clock). */
private void
test9()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%H"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `H', verify this function "
	       "converts the characters which shows the hour(24-hour clock).";

  DBUG_ENTER ("test9");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_24h, format[i], &conv_time);
      print_tm ("test9", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The hour is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `I', verify this function converts the
   characters which shows the hour(12-hour clock). */
private void
test10()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%I"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `I', verify this function "
	       "converts the characters which shows the hour(12-hour clock).";

  DBUG_ENTER ("test10");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_12h, format[i], &conv_time);
      print_tm ("test10", &conv_time);
      if ((ans_time.tm_hour % 12) == (conv_time.tm_hour % 12))
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The hour is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `j', verify this function converts the
   characters which shows the day number of the year. */
private void
test11()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%j"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `j', verify this function "
	       "converts the characters which shows the day number of the "
	       "year.";

  DBUG_ENTER ("test11");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_yday, format[i], &conv_time);
      print_tm ("test11", &conv_time);
      if ((ans_time.tm_yday % 12) == (conv_time.tm_yday % 12))
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The day number of the year is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `m', verify this function converts the
   characters which shows the month number. */
private void
test12()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%m"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `m', verify this function "
	       "converts the characters which shows the month number.";

  DBUG_ENTER ("test12");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_mon_dec, format[i], &conv_time);
      print_tm ("test12", &conv_time);
      if (ans_time.tm_mon == conv_time.tm_mon)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The month number is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `M', verify this function converts the
   characters which shows the minute. */
private void
test13()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%M"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `M', verify this function "
	       "converts the characters which shows the minute.";

  DBUG_ENTER ("test13");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_minutes, format[i], &conv_time);
      print_tm ("test13", &conv_time);
      if (ans_time.tm_min == conv_time.tm_min)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The minutes are not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `p', verify this function converts the
   characters which is the locale's equivalent of a.m. or p.m.. */
private void
test14()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%p%I"};
  char def_hour12_am_pm[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `p', verify this function "
	       "converts the characters which is the locale's equivalent of "
	       "a.m. or p.m..";

  DBUG_ENTER ("test14");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_hour12_am_pm, "%s %s", def_am_pm, def_12h);
      strptime (def_hour12_am_pm, format[i], &conv_time);
      print_tm ("test14", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The a.m./p.m. is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `r', verify this function converts the
   characters which shows 12-hour clock time using the AM/PM notation. */
private void
test15()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%r"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `r', verify this function "
	       "converts the characters which shows 12-hour clock time using "
	       "the AM/PM notation.";

  DBUG_ENTER ("test15");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_am_pm_time, format[i], &conv_time);
      print_tm ("test15", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_min  == conv_time.tm_min  ||
	  ans_time.tm_min  == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The time using the AM/PM notation is not converted "
		  "correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `R', verify this function converts the
   characters which shows the time as `%H:%M'. */
private void
test16()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%R"};
  char def_H_M[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `R', verify this function "
	       "converts the characters which shows the time as `%H:%M'.";

  DBUG_ENTER ("test16");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_H_M, "%s:%s", def_24h, def_minutes);
      strptime (def_H_M, format[i], &conv_time);
      print_tm ("test16", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_min  == conv_time.tm_min)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The description `%H:%M' is not converted "
		  "correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `S', verify this function converts the
   characters which shows the seconds. */
private void
test17()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%S"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `S', verify this function "
	       "converts the characters which shows the seconds.";

  DBUG_ENTER ("test17");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_second, format[i], &conv_time);
      print_tm ("test17", &conv_time);
      if (ans_time.tm_sec == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The second is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `T', verify this function converts the
   characters which shows the theme as `%H:%M:%S'. */
private void
test18()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%T"};
  char def_H_M_S[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `T', verify this function "
	       "converts the characters which shows the theme as `%H:%M:%S'.";

  DBUG_ENTER ("test18");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_H_M_S, "%s:%s:%s", def_24h, def_minutes, def_second);
      strptime (def_H_M_S, format[i], &conv_time);
      print_tm ("test18", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_min  == conv_time.tm_min  ||
	  ans_time.tm_sec  == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The description `%H:%M:%%S' is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `U', verify this function converts the
   characters which shows the week number of the year (Sunday as the first
   day of the week) as a decimal number. */
private void
test19()
{
  struct tm conv_time;
  int  num, i;
  char def_wd_yw[BUFSIZ];
  char *format[] = {"%U %a"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `U', verify this function "
	       "converts the characters which shows the week number of the "
	       "year (Sunday as the first day of the week) as a decimal "
	       "number.";

  DBUG_ENTER ("test19");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_wd_yw, "%s %s", def_week_dec_s, def_abwday);
      strptime (def_wd_yw, format[i], &conv_time);
      print_tm ("test19", &conv_time);
      if (ans_time.tm_mon  == conv_time.tm_mon ||
	  ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The week number of the year is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `w', verify this function converts the
   characters which shows the weekday as a decimal number, with 0 representing
   Sunday. */ 
private void
test20()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%w"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `w', verify this function "
	       "converts the characters which shows the weekday as a decimal "
	       "number, with 0 representing Sunday.";

  DBUG_ENTER ("test20");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_day_of_week_dec, format[i], &conv_time);
      print_tm ("test20", &conv_time);
      if (ans_time.tm_wday == conv_time.tm_wday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The weekday number is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `W', verify this function converts the
   characters which shows the week number of the year (Monday as the first
   day of the week) as a decimal number. */
private void
test21()
{
  struct tm conv_time;
  int  num, i;
  char def_wd_yw[BUFSIZ];
  char *format[] = {"%W %a"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `W', verify this function "
	       "converts the characters which shows the week number of the "
	       "year (Monday as the first day of the week) as a decimal "
	       "number.";

  DBUG_ENTER ("test21");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_wd_yw, "%s %s", def_week_dec_s, def_abwday);
      strptime (def_wd_yw, format[i], &conv_time);
      print_tm ("test21", &conv_time);
      if (ans_time.tm_mon  == conv_time.tm_mon ||
	  ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The week number of the year is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `x', verify this function converts the
   characters which shows the date using the locale's date format. */
private void
test22()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%x"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `x', verify this function "
	       "converts the characters which shows the date using the "
	       "locale's date format.";

  DBUG_ENTER ("test22");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_prefered_date, format[i], &conv_time);
      print_tm ("test22", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year ||
          ans_time.tm_mon  == conv_time.tm_mon  ||
          ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The date using the locale's data format number is not "
		  "converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `X', verify this function converts the
   characters which shows the time using the locale's time format. */
private void
test23()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%X"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `X', verify this function "
	       "converts the characters which shows the time using the "
	       "locale's time format.";

  DBUG_ENTER ("test23");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_prefered_time, format[i], &conv_time);
      print_tm ("test23", &conv_time);
      if (ans_time.tm_sec  == conv_time.tm_sec  ||
          ans_time.tm_min  == conv_time.tm_min  ||
          ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The time using the locale's data format number is not "
		  "converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `y', verify this function converts the
   characters which shows the year in 2 figure. */
private void
test24()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%y"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `y', verify this function "
	       "converts the characters which shows the year in 2 figure.";

  DBUG_ENTER ("test24");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_double_year, format[i], &conv_time);
      print_tm ("test24", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The year in 2 fugures is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Y', verify this function converts the
   characters which shows the year in 4 figure. */
private void
test25()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Y"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Y', verify this function "
	       "converts the characters which shows the year in 4 figure.";

  DBUG_ENTER ("test25");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (def_full_year, format[i], &conv_time);
      print_tm ("test25", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The year in 4 fugures is not converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `%' (i.e. the orthography is `%%', verify
   this function replace with `%'. */
private void
test26()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%p%%%I"};
  char def_hour12_am_pm[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `%' (i.e. the orthography is "
	       "`%%', verify this function replace with `%'.";

  DBUG_ENTER ("test26");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_hour12_am_pm, "%s%%%s", def_am_pm, def_12h);
      strptime (def_hour12_am_pm, format[i], &conv_time);
      print_tm ("test26", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The `%%' is not interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Ec', verify this function converts the
   characters which is the locale's alternative appropriate date and time
   representation. */
private void
test27()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Ec"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Ec', verify this function "
	       "converts the characters which is the locale's alternative "
	       "appropriate date and time representation.";

  DBUG_ENTER ("test27");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_d_t_fmt, format[i], &conv_time);
      print_tm ("test27", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year ||
	  ans_time.tm_mon  == conv_time.tm_mon  ||
	  ans_time.tm_mday == conv_time.tm_mday ||
	  ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_min  == conv_time.tm_min  ||
	  ans_time.tm_sec  == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The locale's alternative appropriate date and time is not "
		  "converted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `EC', verify this function converts the
   characters which is the name of the base year (period) in the locale's
   alternative representation. */
private void
test28()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%EC"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `EC', verify this function "
	       "converts the characters which is the name of the base year "
	       "(period) in the locale's alternative representation.";

  DBUG_ENTER ("test28");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_year_name, format[i], &conv_time);
      print_tm ("test28", &conv_time);
      if (conv_time.tm_year == alt_base_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The conversion characters `EC' is not interpreted "
		  "correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Ex', verify this function converts the
   characters which is the locale's alternative date representation. */ 
private void
test29()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Ex"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Ex', verify this function "
	       "converts the characters which is the locale's alternative "
	       "date representation.";

  DBUG_ENTER ("test29");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_date, format[i], &conv_time);
      print_tm ("test29", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year ||
	  ans_time.tm_mon  == conv_time.tm_mon  ||
	  ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The locale's alternative date representation is not "
		  "interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `EX', verify this function converts the
   characters which is the locale's alternative time representation. */ 
private void
test30()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%EX"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `EX', verify this function "
	       "converts the characters which is the locale's alternative "
	       "time representation.";

  DBUG_ENTER ("test30");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_time, format[i], &conv_time);
      print_tm ("test30", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour ||
	  ans_time.tm_min  == conv_time.tm_min  ||
	  ans_time.tm_sec  == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The locale's alternative time representation is not "
		  "interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Ey', verify this function converts the
   characters which is the offset from `%EC' (year only) in the locale's
   alternative representation. */
private void
test31()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%EC%Ey"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Ey', verify this function "
	       "converts the characters which is the offset from `%EC' "
	       "(year only) in the locale's alternative representation.";

  DBUG_ENTER ("test31");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_year_dec, format[0], &conv_time);
      print_tm ("test31", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The locale's alternative time representation is not "
		  "interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `EY', verify this function converts the
   characters which is the full alternative year representation. */
private void
test32()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%EY"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `EY', verify this function "
	       "converts the characters which is the full alternative year "
	       "representation.";

  DBUG_ENTER ("test32");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_year, format[i], &conv_time);
      print_tm ("test32", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The locale's alternative year representation is not "
		  "interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Od' or `Oe', verify this function
   converts the character which shows the day of the month using the
   locale's alternative numeric symbols. */
private void
test33()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Od", "%Oe"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Od' or `Oe', verify this "
	       "function converts the character which shows the day of the "
	       "month using the locale's alternative numeric symbols.";

  DBUG_ENTER ("test33");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_day, format[i], &conv_time);
      print_tm ("test33", &conv_time);
      if (ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The day of month using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OH', verify this function converts the
   character which shows the hour (24-hour clock) using the locale's
   alternative numeric symbols. */
private void
test34()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%OH"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OH', verify this function "
	       "converts the character which shows the hour (24-hour clock) "
	       "using the locale's alternative numeric symbols.";

  DBUG_ENTER ("test34");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_24h, format[i], &conv_time);
      print_tm ("test34", &conv_time);
      if (ans_time.tm_hour == conv_time.tm_hour)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The hour using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OI', verify this function converts the
   character which shows the hour (12-hour clock) using the locale's
   alternative numeric symbols. */
private void
test35()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%OI"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OI', verify this function "
	       "converts the character which shows the hour (12-hour clock) "
	       "using the locale's alternative numeric symbols.";

  DBUG_ENTER ("test35");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_12h, format[i], &conv_time);
      print_tm ("test35", &conv_time);
      if ((ans_time.tm_hour % 12) == (conv_time.tm_hour % 12))
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The hour using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Om', verify this function converts the
   character which shows the month using the locale's alternative numeric
   symbols. */
private void
test36()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Om"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Om', verify this function "
	       "converts the character which shows the month using the "
	       "locale's alternative numeric symbols.";

  DBUG_ENTER ("test36");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_month, format[i], &conv_time);
      print_tm ("test36", &conv_time);
      if (ans_time.tm_mon == conv_time.tm_mon)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The month using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OM', verify this function converts the
   character which shows the minutes using the locale's alternative numeric
   symbols. */
private void
test37()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%OM"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OM', verify this function "
	       "converts the character which shows the minutes using the "
	       "locale's alternative numeric symbols.";

  DBUG_ENTER ("test37");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_minutes, format[i], &conv_time);
      print_tm ("test37", &conv_time);
      if (ans_time.tm_min == conv_time.tm_min)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The minutes using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OS', verify this function converts the
   character which shows the seconds using the locale's alternative numeric
   symbols. */
private void
test38()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%OS"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OS', verify this function "
	       "converts the character which shows the seconds using the "
	       "locale's alternative numeric symbols.";

  DBUG_ENTER ("test38");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_second, format[i], &conv_time);
      print_tm ("test38", &conv_time);
      if (ans_time.tm_sec == conv_time.tm_sec)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The minutes using the locale's alternative numeric "
		  "symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OU', verify this function converts the
   character which shows the week number of the year (Sunday as the first
   day of the week) using the locale's alternative numeric symbols. */
private void
test39()
{
  struct tm conv_time;
  int  num, i;
  char def_wd_yw[BUFSIZ];
  char *format[] = {"%OU %a"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OU', verify this function "
	       "converts the character which shows the week number of the "
	       "year (Sunday as the first day of the week) using the "
	       "locale's alternative numeric symbols.";

  DBUG_ENTER ("test39");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_wd_yw, "%s %s", alt_num_weeknum_m, def_abwday);
      strptime (def_wd_yw, format[i], &conv_time);
      print_tm ("test39", &conv_time);
      if (ans_time.tm_mon  == conv_time.tm_mon ||
	  ans_time.tm_mday == conv_time.tm_mday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The week number of the year  using the locale's "
		  "alternative numeric symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Ow', verify this function converts the
   character which shows the number of the weekday (Sunday=0) using the
   locale's alternative numeric symbols. */
private void
test40()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Ow"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Ow', verify this function "
	       "converts the character which shows the number of the weekday "
	       "(Sunday=0) using the locale's alternative numeric symbols.";

  DBUG_ENTER ("test40");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_day_of_week, format[i], &conv_time);
      print_tm ("test40", &conv_time);
      if (ans_time.tm_wday == conv_time.tm_wday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The number of the weekday using the locale's "
		  "alternative numeric symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `OW', verify this function converts the
   character which shows the week number of the year (Monday as the first
   day of the week) using the locale's alternative numeric symbols. */
private void
test41()
{
  struct tm conv_time;
  int  num, i;
  char def_wd_yw[BUFSIZ];
  char *format[] = {"%OW %a"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `OW', verify this function "
	       "converts the character which shows the week number of the "
	       "year (Monday as the first day of the week) using the "
	       "locale's alternative numeric symbols.";

  DBUG_ENTER ("test41");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      sprintf (def_wd_yw, "%s %s", alt_num_weeknum_m, def_abwday);
      strptime (def_wd_yw, format[i], &conv_time);
      print_tm ("test41", &conv_time);
      if (ans_time.tm_wday == conv_time.tm_wday)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The week number of the year using the locale's "
		  "alternative numeric symbols is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the conversion character is `Oy', verify this function converts the
   character which shows the year (offset from `%C') using the locale's
   alternative numeric symbols. */
private void
test42()
{
  struct tm conv_time;
  int  num, i;
  char *format[] = {"%Oy"};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the conversion character is `Oy', verify this function "
	       "converts the character which shows the year (offset from "
	       "`%C') using the locale's alternative numeric symbols.";

  DBUG_ENTER ("test42");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  num = sizeof(format) / sizeof(format[0]);
  for (i = 0; i < num; i++)
    {
      memset (&conv_time, '\0', sizeof (struct tm));
      strptime (alt_num_year, format[i], &conv_time);
      print_tm ("test42", &conv_time);
      if (ans_time.tm_year == conv_time.tm_year)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The year using the locale's alternative numeric symbols "
		  "is interpreted correctly.");
	  DBUG_VOID_RETURN;
	}
    }

  PATH_XS_RPT(num);
  DBUG_VOID_RETURN;
}


/* If the call is successful, verify this function returns a pointer to the
   character following the last character parsed. */
private void
test43()
{
  struct tm conv_time;
  char *format = "aa";
  char *str = "aax";
  char *ret;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the call is successful, verify this function returns a "
	       "pointer to the character following the last character parsed.";

  DBUG_ENTER ("test43");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  memset (&conv_time, '\0', sizeof (struct tm));
  ret = strptime (str, format, &conv_time);
  if (ret == strchr (str, 'x'))
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
      DBUG_VOID_RETURN;
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If the call is unsuccessful, verify this function returns a NULL is
   returned. */
private void
test44()
{
  struct tm conv_time;
  char *format = "a";
  char *str = "x";
  char *ret;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the call is unsuccessful, verify this function returns a "
	       "NULL is returned.";

  DBUG_ENTER ("test44");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  memset (&conv_time, '\0', sizeof (struct tm));
  ret = strptime (str, format, &conv_time);
  if (ret == NULL)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
      DBUG_VOID_RETURN;
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
