/*
 * LI18NUX2K.L1/base/vfprintf/vfprintf.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <locale.h>
#include <wchar.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();

#define NO_TESTS 5
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,   1,
	test2,   2,
	test3,   3,
	test4,   4,
	test5,   5,
	NULL, 0
};


/* Like fprintf with using vfprintf(). */
private int
va_fprintf (FILE *fp, char *format, ...)
{
  va_list argp;
  int ret;

  va_start (argp, format);
  ret = vfprintf (fp, format, argp);
  va_end (argp);

  return (ret);
}


/* If format has `e', `E', `f', `g' or `G' flag, verify the output symbol
   which shows decimal point changes on the current locale. */
private void
test1()
{
  int  i, num, ret;
  FILE *fp;
  double fraction = 1.234;
  int  dp = '*';
  char *format[] = {"%le", "%lE", "%lf", "%lg", "%lG"};
  char mbs[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If format has `e', `E', `f', `g' or `G' flag, verify the "
	       "output symbol which shows decimal point changes on the "
	       "current locale.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  num = sizeof(format) / sizeof(format[0]);

  for (i = 0; i < num; i++)
    {
      if ((fp = fopen ("testfile", "w")) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("Cannot open 'testfile'");
	  DBUG_VOID_RETURN;
	}

      ret = fprintf (fp, format[i], fraction);
      fclose (fp);

      if ((fp = fopen ("testfile", "r")) == NULL)
	{
	  xx_rpt (FAILURE);
	  in_rpt ("Cannot open 'testfile'");
	  DBUG_VOID_RETURN;
	}

      fgets (mbs, BUFSIZ, fp);
      
      if (strchr (mbs, dp) != NULL)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("A wrong radix characer is wrtten.");
	}
      fclose (fp);
    }
  
  PATH_XS_RPT (num);
  DBUG_VOID_RETURN;
}


/* If a conversion specifier is `c' and `l' specifier is present, verify the
   wint_t argument is converted as if by an `ls' conversion specification with
   no precision and an argument that points to a two element array of type
   wchar_t, the first element of which contains the wint_t argument to the
   `ls' conversion specification and the second element contains a null wide
   character. */
private void
test2()
{
  int  i, num, ret;
  FILE *fp;
  wint_t  wc = 0x3042;	/* あ */
  wchar_t wcs[2];
  char *formatc = "%lc\n", *formats = "%ls\n";
  char mbsc[BUFSIZ], mbss[BUFSIZ];
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If a conversion specifier is `c' and `l' specifier is "
	       "present, verify the wint_t argument is converted as if by an "
	       "`ls' conversion specification with no precision and an "
	       "argument that points to a two element array of type wchar_t, "
	       "the first element of which contains the wint_t argument to "
	       "the `ls' conversion specification and the second element "
	       "contains a null wide character.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fprintf (fp, formatc, wc);
  wcs[0] = wc;	wcs[1] = L'\0';
  ret = fprintf (fp, formats, wcs);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  fgets (mbsc, BUFSIZ, fp);
  fgets (mbss, BUFSIZ, fp);

  if (strcmp (mbsc, mbss) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The conversion specifier `c' is not interpreted correctly");
      DBUG_PRINTF ("test2", "(%%c): %s", mbsc);
      DBUG_PRINTF ("test2", "(%%s): %s", mbss);
    }
  fclose (fp);

  PATH_XS_RPT (1);
  DBUG_VOID_RETURN;
}


/* When a conversion specifier is `ls', and the precision is less than or
   equal to the byte length of the converted character, verify a wide
   characters starting at a pointer to character given by the argument is
   converted to a multibyte characters as if wcsrtombs() function called
   with initial conversion state and the converted multibyte characters are
   written. (Notice: Any bytes which is not formed multibyte character is
   not written.) */
private void
test3()
{
  int  i, num, ret;
  FILE *fp;
  wchar_t wcs[] = {L'a', 0x00E4, 0x3042, L'\0'};	  /* 7byte. */
  char *format = "%.5ls";
  char mbs[BUFSIZ];
  char *ans    = "aä";
  size_t mbslen, anslen, cmplen;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When a conversion specifier is `ls', and the precision is "
	       "less than or equal to the byte length of the converted "
	       "character, verify a wide characters starting at a pointer to "
	       "character given by the argument is converted to a multibyte "
	       "characters as if wcsrtombs() function called with initial "
	       "conversion state and the converted multibyte characters are "
	       "written. (Notice: Any bytes which is not formed multibyte "
	       "character is not written.)";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  ret = fprintf (fp, format, wcs);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  fgets (mbs, BUFSIZ, fp);

  mbslen = strlen (mbs);
  anslen = strlen (ans);
  cmplen = mbslen > anslen ? mbslen : anslen;

  if (memcmp (mbs, ans, cmplen) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The conversion specifier `s' is not interpreted correctly");
      DBUG_PRINTF ("test3", "mbs: %s", mbs);
      DBUG_PRINTF ("test3", "ans: %s", ans);
    }
  fclose (fp);

  PATH_XS_RPT (1);
  DBUG_VOID_RETURN;
}


/* When a conversion specifier is `s' and `l' specifier is present, and if
   the precision is more than the length of the converted wide character,
   verify a wide character string starting at a pointer to character given
   by the argument is converted to a multibyte character string as if by
   calling the wcsrtombs() function with initial conversion state and the
   the multibyte character string is written. */
private void
test4()
{
  int  i, num, ret;
  FILE *fp;
  wchar_t wcs[] = {L'a', 0x00E4, 0x3042, L'\0'};	  /* 7byte. */
  char *format = "%.8ls";
  char mbs[BUFSIZ];
  char *ans    = "aäあ";
  size_t mbslen, anslen, cmplen;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "When a conversion specifier is `s' and `l' specifier is "
	       "present, and if the precision is more than the length of the "
	       "converted wide character, verify a wide character string "
	       "starting at a pointer to character given by the argument is "
	       "converted to a multibyte character string as if by calling "
	       "the wcsrtombs() function with initial conversion state and "
	       "the the multibyte character string is written.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }
  ret = fprintf (fp, format, wcs);
  fclose (fp);

  if ((fp = fopen ("testfile", "r")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  fgets (mbs, BUFSIZ, fp);

  mbslen = strlen (mbs);
  anslen = strlen (ans);
  cmplen = mbslen > anslen ? mbslen : anslen;

  if (memcmp (mbs, ans, cmplen) == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The conversion specifier `s' is not interpreted correctly");
      DBUG_PRINTF ("test4", "mbs: %s\t mbslen = %d", mbs, mbslen);
      DBUG_PRINTF ("test4", "ans: %s\t anslen = %d", ans, anslen);
    }
  fclose (fp);

  PATH_XS_RPT (1);
  DBUG_VOID_RETURN;
}



/* After executing this function correctly, verify the stream is changed to
   byte oriented. */
private void
test5()
{
  FILE *fp;
  int  ret;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "After executing this function correctly, verify the stream "
	       "is changed to byte oriented.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  if ((fp = fopen ("testfile", "w")) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot open 'testfile'");
      DBUG_VOID_RETURN;
    }

  ret = fprintf (fp, "Hello World!");

  if (fwide (fp, 0) < 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The stream type is changed by a mistake.");
    }

  fclose (fp);

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
