/*
 * LI18NUX2K.L1/base/wcpcpy/wcpcpy.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define __USE_GNU
#include <wchar.h>

private void test1();
private void test2();

#define NO_TESTS 2
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
      {test1, 1},
      {test2, 2},
      {NULL, 0}
};

private void
test1()
{
  int pathok = 0;
  wchar_t dest[16], *src = L"12345";
  int i, src_num = 5;

  DBUG_ENTER ("test1");
  tet_infoline ("Verify the string starting at dest is same as the string");
  tet_infoline ("starting at src.");

  globok = 1;
  (void) wcpcpy (dest, src);

  for (i = 0; i < src_num + 1; i++)
    {
      if (dest[i] == src[i])
	PATH_TRACE;
      else
	break;
    }

  if (pathok != src_num + 1)
    { 
      char message[1024];

      sprintf (message, "dest: %ls, src: %ls", dest, src);
      xx_rpt (FAILURE);
      in_rpt ("A wide character string is not copied correctly.");
      in_rpt (message);
    }

  PATH_XS_RPT (src_num + 1);
  DBUG_VOID_RETURN;
}

private void
test2()
{
  wchar_t *rval;
  int  pathok = 0;
  wchar_t dest[16], *src = L"12345";
  int src_num = 5;

  DBUG_ENTER ("test2");
  tet_infoline ("Verify this function returns a pointer to the end of the");
  tet_infoline ("wide-character string dest.");

  globok = 1;
  rval = wcpcpy (dest, src);

  if (rval == dest + src_num)
    PATH_TRACE;
  else
    {
      char message[1024];

      xx_rpt (FAILURE);
      sprintf (message, "Expected: %p, Result: %p", dest + src_num, rval);
      in_rpt ("The return value is not correct.");
    }
                
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
