/*
 * LI18NUX2K.L1/base/wcpncpy/wcpncpy.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define __USE_GNU
#include <wchar.h>

private void test1();
private void test2();
private void test3();
private void test4();

#define NO_TESTS 4
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
      {test1, 1},
      {test2, 2},
      {test3, 3},
      {test4, 4},
      {NULL, 0}
};

private void
test1()
{
  int pathok = 0;
  wchar_t dest[16], *src = L"12345";
  int i, src_num = 5, n = 16;

  DBUG_ENTER ("test1");
  tet_infoline ("When the length of src (including the terminating L'\0'");
  tet_infoline ("character) is less than or equal to n, verify the string");
  tet_infoline ("starting at dest is same as the string starting at src.");

  globok = 1;
  (void) wcpncpy (dest, src, n);

  for (i = 0; i < src_num + 1; i++)
    {
      if (dest[i] == src[i])
	PATH_TRACE;
      else
	break;
    }

  if (pathok != src_num + 1)
    { 
      char message[1024];

      sprintf (message, "dest: %ls, src: %ls", dest, src);
      xx_rpt (FAILURE);
      in_rpt ("A wide character string is not copied correctly.");
      in_rpt (message);
    }

  PATH_XS_RPT (src_num + 1);
  DBUG_VOID_RETURN;
}

private void
test2()
{
  int pathok = 0;
  wchar_t dest[16] = L"1234567890abcdef", *src = L"12345";
  int i, dest_num = 16, src_num = 5;

  DBUG_ENTER ("test2");
  tet_infoline ("When the length of src is smallter than n, verify the");
  tet_infoline ("remaining wide characters in the array dest are filled");
  tet_infoline ("with L'\0' characters.");

  globok = 1;
  (void) wcpncpy (dest, src, dest_num);

  for (i = src_num; i < dest_num; i++)
    {
      if (dest[i] == L'\0')
	PATH_TRACE;
      else
	break;
    }

  if (pathok != dest_num - src_num)
    { 
      xx_rpt (FAILURE);
      in_rpt ("The remaining wide characters in the array dest are not");
      in_rpt ("filled with L'\0' characters.");
    }

  PATH_XS_RPT (dest_num - src_num);
  DBUG_VOID_RETURN;
}

private void
test3()
{
  int pathok = 0;
  wchar_t dest[16] = L"XXXXXXXXXXXXXXXX", *src = L"12345";
  int i, n = 3;

  DBUG_ENTER ("test3");
  tet_infoline ("When the length of src is bigger than n, verify that only");
  tet_infoline ("n wide characters are written at dest.");

  globok = 1;
  (void) wcpncpy (dest, src, n);

  for (i = 0; i < n; i++)
    {
      if (dest[i] == src[i])
	PATH_TRACE;
      else
	break;
    }

  if (dest[i] == L'X') /* Check the next character is not changed. */
    PATH_TRACE;

  if (pathok != n + 1)
    { 
      char message[1024];

      sprintf (message, "dest: %ls, src: %ls", dest, src);
      xx_rpt (FAILURE);
      in_rpt ("A wide character string is not copied correctly.");
      tet_infoline (message);
    }

  PATH_XS_RPT (n + 1);
  DBUG_VOID_RETURN;
}

private void
test4()
{
  wchar_t *rval;
  int  pathok = 0;
  wchar_t dest[16], *src = L"12345";
  int src_num = 5;

  DBUG_ENTER ("test4");
  tet_infoline ("Verify this function returns a pointer to the wide");
  tet_infoline ("character one past the last non-null character written.");

  globok = 1;
  rval = wcpncpy (dest, src, src_num);

  if (rval == dest + src_num)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }
                
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
