/*
 * LI18NUX2K.L1/base/wcscoll/wcscoll.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <locale.h>
#include <wchar.h>

private char *test_locale = "LTP_1.UTF-8";

private wchar_t	wcs[] = {0x00E4, 0x00E4, 0x00E4, L'\0'};
private wchar_t	les[] = L"aaa";
private wchar_t	equ[] = {0x00E4, 0x00E4, 0x00E4, L'\0'};
private wchar_t	grt[] = L"bbb";

private wchar_t wcs2[] = L"Ch";
private wchar_t les2[] = L"Cz";

private void test1();
private void test2();
private void test3();

#define NO_TESTS 3
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	NULL, 0
};


/* If a wide character string starting at s1 is less than a wide character
   string starting at s2, verify this function returns negative value. The
   comparison is executed according to the collating sequence of the current
   locale. */
private void
test1()
{
  int  rval;
  int  pathok = 0;
  char *desc = "If a wide character string starting at s1 is less than a wide "
	       "character string starting at s2, verify this function returns "
	       "negative value. The comparison is executed according to the "
	       "collating sequence of the current locale.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale (LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  globok = 1;

  rval = wcscoll (les, wcs);
  if (rval < 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  /* for collating elements `Ch' */
  rval = wcscoll (les2, wcs2);
  if (rval < 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("When the strings have a collating symbol, "
	      "the return value is not correct.");
    }
                
  PATH_XS_RPT(2);
  DBUG_VOID_RETURN;
}


/* If a wide character string starting at s1 and a wide character string
   starting at s2 are equal, verify this function returns 0. The comparison
   is executed according to the collating sequence of the current locale. */
private void
test2()
{
  int  rval;
  int  pathok = 0;
  char *desc = "If a wide character string starting at s1 and a wide "
	       "character string starting at s2 are equal, verify this "
	       "function returns 0. The comparison is executed according to "
	       "the collating sequence of the current locale.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale (LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  globok = 1;
  rval = wcscoll (equ, wcs);

  if (rval == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }
                
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If a wide character string starting at s1 is greater than a wide character
   string starting at s2, verify this function returns positive value. The
   comparison is executed according to the collating sequence of the current
   locale. */
private void
test3()
{
  int  rval;
  int  pathok = 0;
  char *desc = "If a wide character string starting at s1 is greater than a "
	       "wide character string starting at s2, verify this function "
	       "returns positive value. The comparison is executed according "
	       "to the collating sequence of the current locale.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale (LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }
  globok = 1;
  rval = wcscoll (grt, wcs);
  DBUG_PRINTF("test3", "rval = %d", rval);
  DBUG_PRINTF("test3", "LC_COLLATE: %s", setlocale (LC_COLLATE, NULL));
  DBUG_PRINTF("test3", "grp: %ls", grt);
  DBUG_PRINTF("test3", "wcs: %ls", wcs);
  DBUG_PRINTF("test3", "wcs[0]: %4x", wcs[0]);

  if (rval > 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }
                
  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
