/*
 * LI18NUX2K.L1/base/wcsftime/wcsftime.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <time.h>
#include <locale.h>
#include <wchar.h>
#include <wctype.h>

#define STR_LENGTH 256

private char *test_locale = "LTP_1.UTF-8";

struct tm test_time = 
{
    12,	  /* seconds */
    30,	  /* minutes */
    16,	  /* hours */
    21,	  /* day of the month */
     4,	  /* month */
   101,	  /* year */
     1,	  /* day of the week */
   140,	  /* day in the year */
     0    /* daylight saving time */
};

private wchar_t def_abwday[]         = {0x250F, 0x2513, L'\0'};
private wchar_t def_fullwday[]       = {0x6712, 0x007D, 0x6101, L'\0'};
private wchar_t def_abmonth[]        = {0x3044, 0x3043, L'\0'};
private wchar_t def_fullmonth[]      = {0x7690, L'\0'};
private wchar_t def_d_t_fmt[]        = {L'2', L'0', L'0', L'1', 0x3081,
				        L'0', L'5', 0x00AF,
					L'2', L'1', 0x00C0,
					L' ',
					L'1', L'6', 0x0073,
					L'3', L'0', 0x00CD,
					L'1', L'2', 0x011F, L'\0'};
private wchar_t *def_day             = L"21";
private wchar_t *def_24h	     = L"16";
private wchar_t *def_12h	     = L"04";
private wchar_t *def_yday	     = L"141";
private wchar_t *def_mon_dec         = L"05";
private wchar_t *def_minutes         = L"30";
private wchar_t def_am_pm[]          = {0x3061, 0x0047, L'\0'};
private wchar_t *def_second          = L"12";
private wchar_t *def_week_dec_s      = L"20";
private wchar_t *def_day_of_week_dec = L"1";
private wchar_t *def_week_dec_m      = L"21";
private wchar_t def_prefered_date[]  = {L'2', L'0', L'0', L'1',
				        L'0', L'5', 0x00AF,
					L'2', L'1', 0x00C0, L'\0'};
private wchar_t def_prefered_time[]  = {L'1', L'6', 0x0073,
					L'3', L'0', 0x00CD,
					0x3091, L'1', L'2', L'\0'};
private wchar_t *def_double_year     = L"01";
private wchar_t *def_full_year       = L"2001";

private void test1();
private void test2();
private void test3();
private void test4();
private void test5();
private void test6();
private void test7();
private void test8();
private void test9();
private void test10();
private void test11();
private void test12();
private void test13();
private void test14();
private void test15();
private void test16();
private void test17();
private void test18();
private void test19();
private void test20();
private void test21();
private void test22();
private void test23();
private void test24();

#define NO_TESTS 24
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1,  1,
	test2,  2,
	test3,  3,
	test4,  4,
	test5,  5,
	test6,  6,
	test7,  7,
	test8,  8,
	test9,  9,
	test10, 10,
	test11, 11,
	test12, 12,
	test13, 13,
	test14, 14,
	test15, 15,
	test16, 16,
	test17, 17,
	test18, 18,
	test19, 19,
	test20, 20,
	test21, 21,
	test22, 22,
	test23, 23,
	test24, 24,
	NULL, 0
};


/* Verify this function replaces conversion specifier `a' with the
   abbreviated weekday name according to the current locale. */
private void
test1()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `a' with "
	       "the abbreviated weekday name according to the current locale.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%a", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_abwday) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%a is not converted correctry.");
	DBUG_PRINTF ("test1", "the abbreviated weekday name : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `A' with the full
   weekday name according to the current locale. */
private void
test2()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `A' with "
	       "the full weekday name according to the current locale.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%A", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_fullwday) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %A is not converted correctry.");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `b' with the
   abbreviated month name according to the current locale. */
private void
test3()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `b' with "
	       "the abbreviated month name according to the current locale.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%b", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_abmonth) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %b is not converted correctry.");
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `B' with the full
   month name according to the current locale. */
private void
test4()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `B' with "
	       "the full month name according to the current locale.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%B", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_fullmonth) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %B is not converted correctry.");
	DBUG_PRINTF ("test4", "full month : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `c' with the
   preferred date and time representation for the current locale. */
private void
test5()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `c' with "
	       "the preferred date and time representation for the current "
	       "locale.";

  DBUG_ENTER ("test5");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%c", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_d_t_fmt) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%c is not converted correctry.");
	DBUG_PRINTF ("test5", "preferred date and time : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `d' with the day of
   the month as a decimal number (range 01 to 31). */
private void
test6()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `d' with "
	       "the day of the month as a decimal number (range 01 to 31).";

  DBUG_ENTER ("test6");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%d", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_day) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%d is not converted correctry.");
	DBUG_PRINTF ("test6", "the day of the month : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `H' with the hour as
   a decimal number using a 24-hour clock (range 00 to 23). */
private void
test7()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `H' with "
	       "the hour as a decimal number using a 24-hour clock (range 00 "
	       "to 23).";

  DBUG_ENTER ("test7");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%H", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_24h) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %H is not converted correctry.");
	DBUG_PRINTF ("test7", "hour(24H) : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `I' with the hour as
   a decimal number using a 12-hour clock (range 01 to 12). */
private void
test8()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `I' with "
	       "the hour as a decimal number using a 12-hour clock (range 01 "
	       "to 12).";

  DBUG_ENTER ("test8");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%I", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_12h) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %I is not converted correctry.");
	DBUG_PRINTF ("test8", "hour(12H) : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `j' with the day of
   the year as a decimal number (range 001 to 366). */
private void
test9()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `j' with "
	       "the day of the year as a decimal number (range 001 to 366).";

  DBUG_ENTER ("test9");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%j", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_yday) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %I is not converted correctry.");
	DBUG_PRINTF ("test9", "the day of the year : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier`m' with the month as
   a decimal number (range 01 to 12). */
private void
test10()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier`m' with "
	       "the month as a decimal number (range 01 to 12).";

  DBUG_ENTER ("test10");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%m", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_mon_dec) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %m is not converted correctry.");
	DBUG_PRINTF ("test10", "the month as a decimal number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `M' with the minute
   as a decimal number (range 00 to 59). */
private void
test11()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `M' with "
	       "the minute as a decimal number (range 00 to 59).";

  DBUG_ENTER ("test11");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%M", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_minutes) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %M is not converted correctry.");
	DBUG_PRINTF ("test11", "the minutes as a decimal number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `p' with either AM or
   PM according to the given time value, or the corresponding strings for
   the current locale. */
private void
test12()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `p' with "
	       "either AM or PM according to the given time value, or the "
	       "corresponding strings for the current locale.";

  DBUG_ENTER ("test12");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%p", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_am_pm) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%p is not converted correctry.");
	DBUG_PRINTF ("test12", "the am/pm specifier : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `S' with the second
   as a decimal number (range 00 to 61). */
private void
test13()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `S' with "
	       "the second as a decimal number (range 00 to 61).";

  DBUG_ENTER ("test13");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%S", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_second) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%S is not converted correctry.");
	DBUG_PRINTF ("test13", "the second as a decimal number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `U' with the week
   number of the current year as a decimal number, range 00 to 53, starting
   with the first Sunday as the first day of week 01. */
private void
test14()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `U' with "
	       "the week number of the current year as a decimal number, "
	       "range 00 to 53, starting with the first Sunday as the first "
	       "day of week 01.";

  DBUG_ENTER ("test14");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%U", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_week_dec_s) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %U is not converted correctry.");
	DBUG_PRINTF ("test14", "the week number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `w' with the day of
   the week as a decimal, range 0 to 6, Sunday being 0. */
private void
test15()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `w' with "
	       "the day of the week as a decimal, range 0 to 6, Sunday being "
	       "0.";

  DBUG_ENTER ("test15");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%w", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_day_of_week_dec) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %w is not converted correctry.");
	DBUG_PRINTF ("test15", "tge day of the week as decimal : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `W' with the week
   number of the current year as a decimal number, range 00 to 53, starting
   with the first Monday as the first day of week 01. */
private void
test16()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `W' with "
	       "the week number of the current year as a decimal number, "
	       "range 00 to 53, starting with the first Monday as the first "
	       "day of week 01.";

  DBUG_ENTER ("test16");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%W", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_week_dec_m) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %W is not converted correctry.");
	DBUG_PRINTF ("test16", "the week number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `x' with the
   preferred date representation for the current locale without the time. */
private void
test17()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `x' with "
	       "the preferred date representation for the current locale "
	       "without the time.";

  DBUG_ENTER ("test17");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%x", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_prefered_date) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%x is not converted correctry.");
	DBUG_PRINTF ("test17", "the week number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `X' with the
   preferred time representation for the current locale without the date. */
private void
test18()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `X' with "
	       "the preferred time representation for the current locale "
	       "without the date.";

  DBUG_ENTER ("test18");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%X", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_prefered_time) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %%X is not converted correctry.");
	DBUG_PRINTF ("test18", "the week number : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `y' with the year as
   a decimal number in double figures (range 00 to 99). */
private void
test19()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `y' with "
	       "the year as a decimal number in double figures (range 00 to "
	       "99).";

  DBUG_ENTER ("test19");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%y", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_double_year) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %y is not converted correctry.");
	DBUG_PRINTF ("test19", "the year in double figures : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `Y' with the year as
   a decimal number in full figures. */
private void
test20()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `Y' with "
	       "the year as a decimal number in full figures.";

  DBUG_ENTER ("test20");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%Y", &test_time);

  if (ret > 0)
    if (wcscmp (str, def_full_year) == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %Y is not converted correctry.");
	DBUG_PRINTF ("test20", "the year in full figures : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `Z' with the time
   zone or name or abbreviation. */
private void
test21()
{
  size_t  ret;
  wchar_t str[STR_LENGTH];
  wchar_t def_timezone[STR_LENGTH];
  char	 *p;
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `Z' with "
	       "the time zone or name or abbreviation.";

  DBUG_ENTER ("test21");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  tzset();
  p = getenv("TZ");
  if (p == NULL)
    putenv ("TZ=UTC"); 
  else
    {
      char s[STR_LENGTH];
      const char **spp;
      mbstate_t state;

      strcpy (s, p);
      DBUG_PRINTF ("test21", "multibyte %s", s);
      spp = (const char **)&s;
      memset (&state, '\0', sizeof (mbstate_t));
      (void)mbsrtowcs (def_timezone, spp, STR_LENGTH, &state);
      DBUG_PRINTF ("test21", "wide %ls", s);
    }

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%Z", &test_time);

  if (ret > 0)
    if (p != NULL)
      if (wcscmp (str, def_timezone) == 0)
  PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier %Z is not converted correctry.");
	  DBUG_PRINTF ("test21", "the timezone : %ls", str);
	}
    else
      if (wcscmp (str, L"UTC") == 0)
	PATH_TRACE;
      else
	{
	  xx_rpt (FAILURE);
	  in_rpt ("The specifier %%Z is not converted correctry.");
	  DBUG_PRINTF ("test21", "the timezone : %ls", str);
	}

  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* Verify this function replaces conversion specifier `%' with a literal %
   character. */
private void
test22()
{
  size_t  ret;
  wchar_t  str[STR_LENGTH];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "Verify this function replaces conversion specifier `%' with "
	       "a literal % character.";

  DBUG_ENTER ("test22");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, STR_LENGTH, L"%%", &test_time);

  if (ret > 0)
    if (wcscmp (str, L"%") == 0)
      PATH_TRACE;
    else
      {
	xx_rpt (FAILURE);
	in_rpt ("The specifier %Z is not converted correctry.");
	DBUG_PRINTF ("test22", "the percent character : %ls", str);
      }
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If the length of the wide character string which is made with
   interpretation according to the format is less than or equal to maxsize,
   verify this function returns the length of the wide character string
   except terminating null wide character and stores the wide character
   string (including null terminating character) into the array pointed by
   s. */
private void
test23()
{
  size_t  ret;
  wchar_t str[10];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "If the length of the wide character string which is made "
	       "with interpretation according to the format is less than or "
	       "equal to maxsize, verify this function returns the length of "
	       "the wide character string except terminating null wide "
	       "character and stores the wide character string (including "
	       "null terminating character) into the array pointed by s.";

  DBUG_ENTER ("test23");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, 10, L"123456789", &test_time);

  if (ret == 9)
      PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If the length of the wide character string which is made with
   interpretation according to the format is greater than maxsize,
   verify this function returns 0. */
private void
test24()
{
  size_t  ret;
  wchar_t str[5];
  char   message[64] = "Test Locale is ";
  int    pathok = 0;
  char *desc = "If the length of the wide character string which is made "
    		 "with interpretation according to the format is greater than "
		 "maxsize, verify this function returns 0.";

  DBUG_ENTER ("test24");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  ret = wcsftime (str, 5, L"123456789", &test_time);

  if (ret == 0)
      PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
