/*
 * LI18NUX2K.L1/base/wcswidth/wcswidth.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <ctype.h>
#include <locale.h>
#include <wchar.h>
#include <wctype.h>

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();
private void test3();
private void test4();

#define NO_TESTS 4
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	test3, 3,
	test4, 4,
	NULL, 0
};


/* If pwcs points to a null wide character, verify this function returns 0. */
private void
test1()
{
  int  ret;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If pwcs points to a null wide character, verify this "
	       "function returns 0.";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  ret = wcswidth (L"\0", 1);
  if (ret == 0)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
      DBUG_PRINTF ("test1", "Return value: %d", ret);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If the first n wide character codes in the wide character string pointed to
   by pwcs are a printing wide character, verify this function returns the
   number of column positions to be occupied by the wide character string
   pointed to by pwcs. */ 
private void
test2()
{
  int  i, ret;
  size_t n = 3;
  wchar_t wcs[] = {L'a', 0x00E4, 0x3042, L'a', L'\0'};
  int  width[]  = {   1,      1,      2,    1,     0}, total_width = 0;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If the first n wide character codes in the wide character "
	       "string pointed to by pwcs are a printing wide character, "
	       "verify this function returns the number of column positions "
	       "to be occupied by the wide character string pointed to by "
	       "pwcs.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  for (i = 0; i < n; i++)
    total_width += width[i];

  ret = wcswidth (wcs, n);

  if (ret == total_width)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
      DBUG_PRINTF ("test2", "Return value: %d", ret);
      DBUG_PRINTF ("test2", "Correct value: %d", total_width);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If any of the first n wide character codes in the wide character string
   pointed to by pwcs is not a printing wide character, verify this function
   returns -1. */
private void
test3()
{
  int  ret;
  size_t n = 3;
  wchar_t wcs[] = {L'a', L'\b', 0x3042, L'a', L'\0'};
  int  width[]  = {   1,      1,      2,    1,     0};
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If any of the first n wide character codes in the wide "
	       "character string pointed to by pwcs is not a printing wide "
	       "character, verify this function returns -1.";

  DBUG_ENTER ("test3");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  ret = wcswidth (wcs, n);

  if (ret == -1)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
      DBUG_PRINTF ("test3", "Return value: %d", ret);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}


/* If a null wide character is encountered before n wide character, verify the
   interpretation is stopped at the null wide character. */
private void
test4()
{
  int  i, ret;
  size_t n = 8, null_stands = 5;
  wchar_t wcs[] = {L'a', 0x00E4, 0x3042, L'a', L'\0', L'i', 0x00EF, 0x3044};
  int  width[]  = {   1,      1,      2,    1,    0,    1,       1,      2};
  int  total_width = 0;
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  char *desc = "If a null wide character is encountered before n wide "
	       "character, verify the interpretation is stopped at the null "
	       "wide character.";

  DBUG_ENTER ("test4");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  for (i = 0; i < null_stands; i++)
    total_width += width[i];

  ret = wcswidth (wcs, n);

  if (ret == total_width)
    PATH_TRACE;
  else
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct");
      DBUG_PRINTF ("test4", "Return value: %d", ret);
      DBUG_PRINTF ("test4", "Correct value: %d", total_width);
    }

  PATH_XS_RPT(1);
  DBUG_VOID_RETURN;
}
