/*
 * LI18NUX2K.L1/base/wctrans/wctrans.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <std.h>
#include <dbug.h>
#include <report.h>
#include <tet_api.h>
#include <sysdep.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <locale.h>
#include <wchar.h>
#include <wctype.h>

#define UNICODE_MAX 0xFFFF

private char *test_locale = "LTP_1.UTF-8";

private void test1();
private void test2();

#define NO_TESTS 2
int	no_tests = NO_TESTS;
public 	void  	(*setfunc)()     = NULL;
public 	void  	(*clnfunc)()     = NULL;
public	struct tet_testlist tet_testlist[] = {
	test1, 1,
	test2, 2,
	NULL, 0
};


/* If the character string starting at property is defined string as
   conversion directive which is defined on the current locale, verify this
   function returns the value corresponded that conversion directive. (the
   value is non-zero) */
private void
test1()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  long ucode;
  char *desc = "If the character string starting at property is defined "
	       "string as conversion directive which is defined on the "
	       "current locale, verify this function returns the value "
	       "corresponded that conversion directive. (the value is "
	       "non-zero)";

  DBUG_ENTER ("test1");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;

  /* Ordinary character classes. */
  if (wctrans ("tolower"))  PATH_TRACE;
  if (wctrans ("toupper"))  PATH_TRACE;

  /* Expanded character classes. */
  if (wctrans ("tobsuit"))  PATH_TRACE;
  if (wctrans ("towsuit"))  PATH_TRACE;

  if (pathok != 4)
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(4);
  DBUG_VOID_RETURN;
}


/* If the character string starting at property is not valid string as 
   conversion directive which is defined on the current locale, verify this
   function returns 0. */
private void
test2()
{
  char message[64] = "Test Locale is ";
  int  pathok = 0;
  long ucode;
  char *desc = "If the character string starting at property is not valid "
	       "string as conversion directive which is defined on the "
	       "current locale, verify this function returns 0.";

  DBUG_ENTER ("test2");
  tet_infoline (desc);

  if (setlocale(LC_ALL, test_locale) == NULL)
    {
      xx_rpt (FAILURE);
      in_rpt ("Cannot use test locale.");
      DBUG_VOID_RETURN;
    }

  strcat (message, test_locale);
  tet_infoline (message);

  globok = 1;
  if (!wctrans ("chess"))     PATH_TRACE;
  if (!wctrans ("zodiacal"))  PATH_TRACE;

  if (pathok != 2)
    {
      xx_rpt (FAILURE);
      in_rpt ("The return value is not correct.");
    }

  PATH_XS_RPT(2);
  DBUG_VOID_RETURN;
}
