/*
 * LI18NUX2K.L1/gui/FontServer/dispout.c
 * 
 * Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
 * (X/Open)
 * trading as The Open Group
 * Copyright (c) 2001, 2003 International Business Machines Corp.
 * All rights reserved except as granted by this License.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the "Artistic License" which comes with this
 * Kit, with the following modification:
 * a) "executable(s)" should be interpreted to include
 * "test case(s)"
 * b) if you wish to make changes as defined in clause 2 and 3, and
 * distribute a modified version of this package, then
 * clauses 3c and 4c are required
 * c) Clause 7 is rephrased as follows: "Subroutines supplied by you
 * and linked into this Package shall not be considered part of this
 * Package".
 *
 *
 * X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
 * LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * You should have received a copy of the Artistic License with this
 * Kit, in the file named "Artistic".  If not, we'll be glad to provide one.
 */

#include <stdio.h>
#include <locale.h>
#include <X11/Xlib.h>
#define MAX_NUMS 20

static int Error;
static int Resourceid; /* Place to save BadValues */

/* unexp_err function */
int unexp_err (Display* d, XErrorEvent* errevent)
{
  char text[100];

  XGetErrorText (d, errevent->error_code, text, 100);
}

/* The endcall() routine does all common cleanup code that
   should be called after the routine under test has been
   called.  XSync() needs to be called before this. */
void endcall (Display* d)
{
  extern int unexp_err();

  XSync (d, False);
  XSetErrorHandler (unexp_err);

  if (geterr() != Success) 
    {
      printf("NG ECode[%d] RsrcID[0x%x]\n", Error, Resourceid);
      exit (1);
    }
}

/* geterr function */
int geterr ()
{
  return (Error);
}

/* error_status function */
int error_status (Display* d, XErrorEvent* errevent)
{
  /* The test for Success means that the first error will be recorded
     rather than the last.  This is usually the most intuitively
     related to the problem.  However there is no guarantee when
     multiple errors occur which will get reported and in what order.
     So all tests look for at most one error.  */
  if (Error == Success) 
    {
      Error = errevent->error_code;
      Resourceid = errevent->resourceid;
    }
  return (0);      /* This is not used (?) */
}

/* reseterr function */
void reseterr()
{
  Error = Success;
}

/* startcall function */
void startcall (Display* d)
{
  XSync(d, True);
  reseterr();
  XSetErrorHandler(error_status);
}

int main ()
{
  Display* d;
  Window w;
  GC gc;
  Font fonts[MAX_NUMS], ft;
  XGCValues gcv;
  unsigned long fg, bg;
  int i=0, x, y;
  char* dispstr="123456789012345678901234567890";

  /* Initialize Display */
  if (!(d = XOpenDisplay(NULL))) {
      fprintf (stderr, "Cannot open display\n");
      exit (1);
  }

  /* Create a window */
  fg = BlackPixel(d, DefaultScreen (d));
  bg = WhitePixel(d, DefaultScreen (d));
  w = XCreateSimpleWindow (d, DefaultRootWindow (d), 100, 100, 200, 200, 0, fg, bg);
  XMapWindow (d, w);

  {
    /* Set error handler */
    startcall (d);
  
    /* Load font */
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--40-40-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[40 10.29 0 40]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[40 0 10.29 40]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[40 0 0 40]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[0 40 40 0]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[40 40 40 0]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[0 40 40 40]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[40 40 40 0]-0-0-p-0-iso10646-1");
    fonts[i++] = XLoadFont (d, "-dummyoutline-gothic-medium-r-normal--0-[45 0 0 35]-0-0-p-0-iso10646-1");
    fonts[i++] = 0;
  
    /* Check status */
    endcall(d);
  }

  /* Create GC */
  gcv.foreground = fg;
  gcv.background = bg;
  gc = XCreateGC (d, w, (GCForeground | GCBackground), &gcv);

  {
    /* Set error handler */
    startcall (d);
  
    /* Display text/string */
    i=0; 
    while ((ft=fonts[i++]))
      {
        x=10; y=50;
        XSetFont (d, gc, ft);
        XDrawString (d, w, gc, x, y, dispstr, strlen (dispstr));
        XDrawString (d, w, gc, x, y+50, dispstr, strlen (dispstr));
        XDrawString (d, w, gc, x, y+100, dispstr, strlen (dispstr));
        XDrawString (d, w, gc, x, y+150, dispstr, strlen (dispstr));
  
        XFlush (d);
        sleep (2);
        XClearWindow (d, w);
      }
  
    /* Check status */
    endcall(d);
  }

  XFlush (d);
  XFreeGC (d, gc);
  XDestroyWindow (d, w);
  XCloseDisplay (d);
}
