#/bin/sh
#
# LI18NUX2K.L1/hdr/wchar_h/wchar_h.sh
#
# Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
# (X/Open)
# trading as The Open Group
# Copyright (c) 2001, 2003 International Business Machines Corp.
# All rights reserved except as granted by this License.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the "Artistic License" which comes with this
# Kit, with the following modification:
# a) "executable(s)" should be interpreted to include
# "test case(s)"
# b) if you wish to make changes as defined in clause 2 and 3, and
# distribute a modified version of this package, then
# clauses 3c and 4c are required
# c) Clause 7 is rephrased as follows: "Subroutines supplied by you
# and linked into this Package shall not be considered part of this
# Package".
#
#
# X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
# LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
# You should have received a copy of the Artistic License with this
# Kit, in the file named "Artistic".  If not, we'll be glad to provide one.


tet_startup="startup"			# startup function
tet_cleanup="cleanup"			# cleanup function
iclist="ic1"
ic1="tp1 tp2 tp3 tp4"

# Check data type.
tp1()
{
	tpstart "Test for wchar.h."
	tet_infoline "Check the following data types are defined:"
	tet_infoline " wchar_t wint_t size_t mbstate_t"

	check_datatypes wchar_t wint_t size_t mbstate_t

	if test ${?} = 0 ; then
	  tet_infoline "All data type are defined."
	  tet_result PASS
	else
	  tet_infoline "Some data type are not defined."
	  tet_result FAIL
	fi
}

# Check tm structure.
tp2()
{
	tpstart "Test for wchar.h."
	tet_infoline "Check the following structure is defined (But imcompletely):"
	tet_infoline " tm"

	echo "#include <${header_name}>"	 > ./tm.c
	echo ""					>> ./tm.c
	echo "int main(void)"			>> ./tm.c
	echo "{"			        >> ./tm.c
	echo "  struct tm *struct_p;"		>> ./tm.c
	echo "  return 0;"			>> ./tm.c
	echo "}"				>> ./tm.c

	cc -o ./tm.out ./tm.c > /dev/null 2>&1

	if test ${?} = 0 ; then
	  tet_infoline "The structure tm is defined."
	  tet_result PASS
	else
	  tet_infoline "The structure tm is not defined."
	  tet_result FAIL
	fi
}

# Check macros.
tp3()
{
	tpstart "Test for wchar.h."
	tet_infoline "Check the following macros are defined:"
	tet_infoline " NULL WEOF WCHAR_MAX WCHAR_MIN"

	check_macros NULL WEOF WCHAR_MAX WCHAR_MIN

	if test ${?} = 0 ; then
	  tet_infoline "All macros are defined."
	  tet_result PASS
	else
	  tet_infoline "Some macros are not defined."
	  tet_result FAIL
	fi
}

# Check functions.
tp4()
{
	tpstart "Test for wchar.h."
	tet_infoline "Check the following functions are defined:"
	tet_infoline " fwprintf fwscanf wprintf wscanf swprintf swscanf"
	tet_infoline " vfwprintf vwprintf vswprintf"
	tet_infoline " fgetwc fgetws fputwc fputws getwc getwchar putwc"
	tet_infoline " putwchar ungetwc fwide wcstod wcstol wcstoul wcscpy"
	tet_infoline " wcsncpy wcscat wcsncat wcscmp wcsncmp wcsxfrm wcschr"
	tet_infoline " wcscspn wcspbrk wcsrchr wcsspn wcsstr wcstok wcslen"
	tet_infoline " wmemchr wmemcmp wmemcpy wmemmove wmemset wcsftime btowc"
	tet_infoline " wctob mbsinit mbrlen mbrtowc wcrtomb mbsrtowcs "
	tet_infoline " wcsrtombs" 

	tet_infoline "* NOTICE *"
	tet_infoline "The following macro is defined before header is included."
	tet_infoline " #define _XOPEN_SOURCE 500"

	export define_macro="_XOPEN_SOURCE 500"
	check_functions fwprintf fwscanf wprintf wscanf swprintf swscanf \
			vfwprintf vwprintf vswprintf fgetwc fgetws fputwc \
			fputws getwc getwchar putwc \
			putwchar ungetwc fwide wcstod wcstol wcstoul wcscpy \
			wcsncpy wcscat wcsncat wcscmp wcsncmp wcsxfrm wcschr \
			wcscspn wcspbrk wcsrchr wcsspn wcsstr wcstok wcslen \
			wmemchr wmemcmp wmemcpy wmemmove wmemset wcsftime \
			btowc wctob mbsinit mbrlen mbrtowc wcrtomb mbsrtowcs \
			wcsrtombs
	unset define_macro

	if test ${?} = 0 ; then
	  tet_infoline "All functions are defined."
	  tet_result PASS
	else
	  tet_infoline "Some function are not defined."
	  tet_result FAIL
	fi
}

startup() # startup function
{
	rm -f out.stdout out.stderr > /dev/null 2>&1

	export header_name="wchar.h"
	rm -f *.c *.o *.out >/dev/null 2>&1
}


cleanup() # clean-up function
{
	rm -f out.stdout out.stderr out.experr >/dev/null 2>&1
	unset header_name
}

# source common shell functions

. $TET_EXECUTE/LIB/i18nfuncs.sh
. $TET_EXECUTE/LIB/shfuncs.sh
. $TET_EXECUTE/LIB/lsbfuncs.sh

# execute shell test case manager - must be last line
. $TET_ROOT/lib/xpg3sh/tcm.sh
