#/bin/sh
#
# LI18NUX2K.L1/utils/tr/tr.sh
#
# Copyright (c) 1991, 1992, 1997, 1998, 1999, 2001 X/Open Company Ltd.
# (X/Open)
# trading as The Open Group
# Copyright (c) 2001, 2003 International Business Machines Corp.
# All rights reserved except as granted by this License.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the "Artistic License" which comes with this
# Kit, with the following modification:
# a) "executable(s)" should be interpreted to include
# "test case(s)"
# b) if you wish to make changes as defined in clause 2 and 3, and
# distribute a modified version of this package, then
# clauses 3c and 4c are required
# c) Clause 7 is rephrased as follows: "Subroutines supplied by you
# and linked into this Package shall not be considered part of this
# Package".
#
#
# X/OPEN, TRADING AS THE OPEN GROUP, AND IBM CORP. DISCLAIM ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL X/OPEN OR IBM CORP. BE
# LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
# You should have received a copy of the Artistic License with this
# Kit, in the file named "Artistic".  If not, we'll be glad to provide one.


#
# Notice: This file have many characters whose encoding is UTF-8
#

tet_startup="startup"			# startup function
tet_cleanup="cleanup"			# cleanup function
iclist="ic1"
ic1="tp1 tp2 tp3 tp4 tp5 tp6 tp7 tp8 tp9 tp10 tp11 tp12 tp13 tp14 tp15 tp16 tp17 tp18 tp19"

tp1()
{
	tet_infoline "If an ordinary multibyte character is in the string, verify the character is matched itself."
	export LANG="LTP_1.UTF-8"

	input_str="aあc"
	convert_str="あ b"
	correct_str="abc"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp2()
{
	tet_infoline "If an array of octal sequence (i.e. \`\octal \octal ....') represented one multibyte character is in the string, verify the array is correctly interpreted as one multibyte character."

	export LANG="LTP_1.UTF-8"

	input_str="aあc"
	convert_str="\\343\\201\\202 \\142"
	correct_str="abc"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_infoline "(each convert specifier character is written in octal code.)"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp3()
{
	tet_infoline "If a range expression is in the string, verify the expression is expanded characters which are in the range according to the collating sequence of the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="aあいうe"
	convert_str="[あ-う] [b-d]"
	correct_str="abcde"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp4()
{
	tet_infoline "If character class is in the string, verify the character class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="a　c"
	convert_str="[:blank:] b"
	correct_str="abc"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp5()
{
	tet_infoline "If equivalence class is in the string, verify the equivalence class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="awc"
	convert_str="[=v=] b"
	correct_str="abc"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp6()
{
	tet_infoline "If a repeat expression is in the string, verify the expression is turned into the string which is repeated character in assignment times."

	export LANG="LTP_1.UTF-8"

	input_str="#123#"
	convert_str="123 [あ*3]"
	correct_str="#あああ#"

	output_str=`echo -n ${input_str} | tr ${convert_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr ${convert_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp7()
{
	tet_infoline "If -c option is attached, verify the string is expanded into the complement the set of characters in the string."
	export LANG="LTP_1.UTF-8"
	flag=0

#
	input_str="aあc"
	convert_str="ac [b*]"
	correct_str="abc"

	output_str=`echo -n ${input_str} | tr -c ${convert_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -c ${convert_str}"
		flag=1
	fi

#
	input_str="aあä"
	convert_str="\\343\\201\\202 [0*]"
	correct_str="0あ0"

	output_str=`echo -n ${input_str} | tr -c ${convert_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -c ${convert_str}"
		flag=1
	fi

#
	input_str="aあいうe"
	convert_str="[あ-う] [0*]"
	correct_str="0BCD0"

	output_str=`echo -n ${input_str} | tr -c ${convert_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -c ${convert_str}"
		flag=1
	fi

#
	input_str="ä　c"
	convert_str="[:blank:] [#*]"
	correct_str="#　#"

	output_str=`echo -n ${input_str} | tr -c ${convert_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -c ${convert_str}"
		flag=1
	fi

#
	input_str="äwc"
	convert_str="[=v=] #"
	correct_str="#v#"

	output_str=`echo -n ${input_str} | tr -c ${convert_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not convert characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -c ${convert_str}"
		flag=1
	fi

##
	if [ ${flag} = 0 ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not expanded into the complement the set of characters correctly."
		tet_result FAIL # fail
	fi
	unset LANG
}
# ---------------

tp8()
{
	tet_infoline "When -d option is attached, if an ordinary multibyte character is in the string, verify the character is matched itself."

	export LANG="LTP_1.UTF-8"

	input_str="aあbあい"
	delete_str="あ"
	correct_str="abい"

	output_str=`echo -n ${input_str} | tr -d ${delete_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d ${delete_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp9()
{
	tet_infoline "When -d option is attached, if an array of octal sequence (i.e. \`\octal \octal ....') represented one multibyte character is in the string, verify the array is correctly interpreted as one multibyte character."

	export LANG="LTP_1.UTF-8"

	input_str="aあbあい"
	delete_str="\\343\\201\\202"
	correct_str="abい"

	output_str=`echo -n ${input_str} | tr -d ${delete_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d ${delete_str}"
		tet_infoline "(each delete specifier character is written in octal code.)"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp10()
{
	tet_infoline "When -d option is attached, if a range expression is in the string, verify the expression is expanded characters which are in the range according to the collating sequence of the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="aあbいcかd"
	delete_str="[あ-お]"
	correct_str="abcかd"

	output_str=`echo -n ${input_str} | tr -d ${delete_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d ${delete_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp11()
{
	tet_infoline "When -d option is attached, if a character class is in the string, verify the character class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="a　b"
	delete_str="[:blank:]"
	correct_str="ab"

	output_str=`echo -n ${input_str} | tr -d ${delete_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d ${delete_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp12()
{
	tet_infoline "* When -d option is attached, if an equivalence class is in the string, verify the equivalence class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="awb"
	delete_str="[=v=]"
	correct_str="ab"

	output_str=`echo -n ${input_str} | tr -d ${delete_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d ${delete_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp13()
{
	tet_infoline "If -c option and -d option is attached, verify the string is expanded into the complement the set of characters in the string."

	export LANG="LTP_1.UTF-8"
	flag=0

#
	input_str="あいう"
	delete_str="い"
	correct_str="い"

	output_str=`echo -n ${input_str} | tr -d -c ${delete_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d -c ${delete_str}"
		flag=1
	fi

#
	input_str="あいう"
	delete_str="\\343\\201\\202"
	correct_str="あ"

	output_str=`echo -n ${input_str} | tr -d -c ${delete_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d -c ${delete_str}"
		flag=1
	fi

#
	input_str="あいうえお"
	delete_str="[い-え]"
	correct_str="あお"

	output_str=`echo -n ${input_str} | tr -d -c ${delete_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d -c ${delete_str}"
		flag=1
	fi

#
	input_str="ä　あ a"
	delete_str="[:blank:]"
	correct_str="　 "

	output_str=`echo -n ${input_str} | tr -d -c ${delete_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d -c ${delete_str}"
		flag=1
	fi

#
	input_str="äwc"
	delete_str="[=v=]"
	correct_str="w"

	output_str=`echo -n ${input_str} | tr -d -c ${delete_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not delete characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -d -c ${delete_str}"
		flag=1
	fi

##
	if [ ${flag} = 0 ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not expanded into the complement the set of characters correctly."
		tet_result FAIL # fail
	fi
	unset LANG
}
# ---------------

tp14()
{
	tet_infoline "When -s option is attached, if an ordinary multibyte character is in the string, verify the character is matched itself."

	export LANG="LTP_1.UTF-8"

	input_str="aあああい"
	squeese_str="あ"
	correct_str="aあい"

	output_str=`echo -n ${input_str} | tr -s ${squeese_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s ${squeese_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp15()
{
	tet_infoline "When -s option is attached, if an array of octal sequence (i.e. \`\octal \octal ....') represented one multibyte character is in the string, verify the array is correctly interpreted as one multibyte character."

	export LANG="LTP_1.UTF-8"

	input_str="aああああい"
	squeese_str="\\343\\201\\202"
	correct_str="aあい"

	output_str=`echo -n ${input_str} | tr -s ${squeese_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s ${squeese_str}"
		tet_infoline "(each squeese specifier character is written in octal code.)"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp16()
{
	tet_infoline "When -s option is attached, if a range expression is in the string, verify the expression is expanded characters which are in the range according to the collating sequence of the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="aああああいいいか"
	squeese_str="[あ-お]"
	correct_str="aあいか"

	output_str=`echo -n ${input_str} | tr -s ${squeese_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s ${squeese_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp17()
{
	tet_infoline "When -s option is attached, if a character class is in the string, verify the character class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="a　　　　　　b"
	squeese_str="[:blank:]"
	correct_str="a　b"

	output_str=`echo -n ${input_str} | tr -s ${squeese_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s ${squeese_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp18()
{
	tet_infoline "* When -s option is attached, if an equivalence class is in the string, verify the equivalence class is expanded characters which are defined in the class according to the current locale."

	export LANG="LTP_1.UTF-8"

	input_str="awwwwwwwwwwwb"
	squeese_str="[=v=]"
	correct_str="awb"

	output_str=`echo -n ${input_str} | tr -s ${squeese_str}`
	
	if [ "${output_str}" = "${correct_str}" ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s ${squeese_str}"
		tet_result FAIL # fail
	fi
	unset LANG
}

tp19()
{
	tet_infoline "If -c option and -s option is attached, verify the string is expanded into the complement the set of characters in the string."

	export LANG="LTP_1.UTF-8"
	flag=0

#
	input_str="あああいいいいうううう"
	squeese_str="い"
	correct_str="あいいいいう"

	output_str=`echo -n ${input_str} | tr -s -c ${squeese_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s -c ${squeese_str}"
		flag=1
	fi

#
	input_str="あああいいいいうううう"
	squeese_str="\\343\\201\\202"
	correct_str="あああいう"

	output_str=`echo -n ${input_str} | tr -s -c ${squeese_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s -c ${squeese_str}"
		flag=1
	fi

#
	input_str="ああああいいううううええええおおおお"
	squeese_str="[い-え]"
	correct_str="あいいううううええええお"

	output_str=`echo -n ${input_str} | tr -s -c ${squeese_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s -c ${squeese_str}"
		flag=1
	fi

#
	input_str="ää　　あああ"
	squeese_str="[:blank:]"
	correct_str="ä　　あ"

	output_str=`echo -n ${input_str} | tr -s -c ${squeese_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s -c ${squeese_str}"
		flag=1
	fi

#
	input_str="ääwwwccc"
	squeese_str="[=v=]"
	correct_str="äwwwc"

	output_str=`echo -n ${input_str} | tr -s -c ${squeese_str}`
	
	if [ "${output_str}" != "${correct_str}" ] ; then
		tet_infoline "This utility can not squeese characters correctly"
		tet_infoline "> echo -n ${input_str} | tr -s -c ${squeese_str}"
		flag=1
	fi

##
	if [ ${flag} = 0 ] ; then
		tet_result PASS # success
	else
		tet_infoline "This utility can not expanded into the complement the set of characters correctly."
		tet_result FAIL # fail
	fi
	unset LANG
}

# ----------------
startup() # startup function
{
          rm -f out.stdout out.stderr > /dev/null 2>&1
}


cleanup() # clean-up function
{
          rm -f out.stdout out.stderr > /dev/null 2>&1
}

# source common shell functions

. $TET_EXECUTE/LIB/i18nfuncs.sh
. $TET_EXECUTE/LIB/shfuncs.sh
. $TET_EXECUTE/LIB/lsbfuncs.sh

# execute shell test case manager - must be last line
. $TET_ROOT/lib/xpg3sh/tcm.sh

