/*
 * Copyright (c) 2002-2003 WIPRO TECHNOLOGIES 
 * Developed for LSB-PAM project by WIPRO TECHNOLOGIES
 */

/*
 * Project: LSB-PAM
 *
 * File: tset/LSB.pam/testcases/pam_getenvlist/pam_getenvlist.c
 * This file contains the test cases for testing the interface
 * pam_getenvlist.
 *
 * Author(s) : Rohit R <rohit.raveendran@wipro.com>, WIPRO TECHNOLOGIES
 *             Laavanya K R <laavanya.gopalan@wipro.com>, WIPRO TECHNOLOGIES
 *
 * Modifications:
 *
 */

#include <stdio.h>
#include <security/pam_appl.h>
#include <security/pam_misc.h>

#include <std.h>
#include <tet_api.h>

/*******************************************************************/

#define NUM_TESTS   2 /* To be updated when number of tests are modified */

private void tc1();
private void tc2();

private void prepare_tests();
private void clean_tests();

public  void (*tet_startup)() = prepare_tests;
public  void (*tet_cleanup)() = clean_tests;

private char *conf_file;
private char *user;
private char *passwd;
private char *input_passwd;

private char echo[256];

private pam_handle_t *pamh;
private struct pam_conv pamc;

public  struct tet_testlist tet_testlist[] = {
        { tc1, 1 },
        { tc2, 2 },
        { NULL, 0 }
};

private void delete_tests(char *msg);

/*******************************************************************/

private void
prepare_tests()
{
    int    retval;

    tet_infoline(" starting tests pam_getenvlist");

    pamh = NULL;
    pamc.conv = &misc_conv;
    pamc.appdata_ptr = NULL;

    conf_file = tet_getvar("LSB_PAM_CONF_FILE");

    if (conf_file == NULL) {
        delete_tests(" tetexec.cfg parameter LAB_PAM_CONF_FILE unset");
        return;
    }

    user = tet_getvar("LSB_PAM_USER");

    if (user == NULL) {
        delete_tests(" tetexec.cfg parameter LAB_PAM_USER unset");
        return;
    }

    retval = pam_start(conf_file, user, &pamc, &pamh);

    if (retval != PAM_SUCCESS) {
        sprintf(echo," pam_start returned %s when expected to succeed",
                                pam_strerror(NULL, retval));
        delete_tests(echo);
        return;
    }

    /*  These are used only for testing purposes. Should be removed */
    pam_misc_setenv(pamh, "PAM_VAR1" , "pam_var_test1", 1);
    pam_misc_setenv(pamh, "PAM_VAR2" , "pam_var_test2", 1);
    pam_misc_setenv(pamh, "PAM_VAR3" , "pam_var_test3", 1);
    pam_misc_setenv(pamh, "PAM_VAR4" , "pam_var_test4", 1);

    return;
}


private void
clean_tests()
{
    if (pamh) {
        pam_end(pamh,0);
    }

    tet_infoline(" end of tests pam_getenvlist");
    return;
}


/*
 *    tc1():
 *        This test case check the interface pam_getenvlist for valid pamh.
 *        The expected return value is a pointer to the complete PAM
 *        environment. This pointer points to an array of pointers to
 *        NULL-terminated strings and must be terminated by a NULL pointer.
 *        Each string has the form "name=value".
 */

private void
tc1()
{
    int    var = 0;
    char   **ptr;
    char   *temp;

    ptr = pam_getenvlist(pamh);

    if (ptr == NULL) {
        tet_infoline(" pam_getenvlist returned NULL when not expected");
        tet_result(TET_FAIL);
        return;
    }

    temp = *ptr;
    var = 0;

    while (temp) {
        free(temp);
        var++;
        temp = *(ptr + var);
    }

    free(ptr);
    tet_result(TET_PASS);
    return;
}


/*
 *    tc2():
 *        This test case check the return value when NULL is passed
 *        for pamh. The expected return value is a NULL pointer
 */

private void
tc2()
{
    char    **ptr;

    ptr = pam_getenvlist((pam_handle_t *)NULL);

    if (ptr != NULL) {
        tet_infoline(" pam_getenvlist returned valid pointer for NULL pamh");
        tet_infoline(" expected return value : NULL pointer");
        tet_result(TET_FAIL);
        return;
    }

    tet_result(TET_PASS);
    return;
}



/*
 *  delete_tests():
 *       This routine is called to stop execution of the test cases
 *       in case of initialization errors.
 */

private void
delete_tests(char *msg)
{
    int    count;

    for (count = 1; count <= NUM_TESTS; count++) {
        tet_delete(count, msg);
    }

    return;
}
