/*
 * Copyright (c) 2002-2003 WIPRO TECHNOLOGIES 
 * Developed for LSB-PAM project by WIPRO TECHNOLOGIES
 */

/*
 * Project: LSB-PAM
 *
 * File: tset/LSB.pam/testcases/pam_start/pam_start.c
 * This file contains the test cases for testing the interface
 * pam_start.
 *
 * Author(s) : Rohit R <rohit.raveendran@wipro.com>, WIPRO TECHNOLOGIES
 *             Laavanya K R <laavanya.gopalan@wipro.com>, WIPRO TECHNOLOGIES
 *
 * Modifications:
 *
 */

#include <stdio.h>
#include <security/pam_appl.h>
#include <security/pam_misc.h>

#include <std.h>
#include <tet_api.h>

/*******************************************************************/

#define NUM_TESTS   3 /* To be updated when number of tests are modified */

private void tc1();
private void tc2();
private void tc3();
/* private void tc4(); */

private void prepare_tests();
private void clean_tests();

public  void (*tet_startup)() = prepare_tests;
public  void (*tet_cleanup)() = clean_tests;

private char *conf_file;
private char *user;

private pam_handle_t *pamh;
private struct pam_conv pamc;

public struct tet_testlist tet_testlist[] = {
        { tc1, 1 },
        { tc2, 2 },
        { tc3, 3 },
/*         { tc4, 4 }, */
        { NULL, 0 }
};

private void delete_tests(char *msg);

/*******************************************************************/

private void
prepare_tests()
{
    int    retval;

    tet_infoline(" starting tests pam_start ");

    pamh = NULL;
    pamc.conv = &misc_conv;
    pamc.appdata_ptr = NULL;

    conf_file = tet_getvar("LSB_PAM_CONF_FILE");

    if (conf_file == NULL) {
        delete_tests(" tetexec.cfg parameter LAB_PAM_CONF_FILE unset");
        return;
    }

    user = tet_getvar("LSB_PAM_USER");

    if (user == NULL) {
        delete_tests(" tetexec.cfg parameter LAB_PAM_USER unset");
        return;
    }

    return;
}


private void
clean_tests()
{
    tet_infoline(" end of tests pam_start");
    return;
}


/*
 * tc1() :
 *     This test case checks the interface pam_start with valid
 *     parameters. The expected return value is PAM_SUCCESS.
 */

private void
tc1()
{
    int    retval;

    retval = pam_start(conf_file, user, &pamc, &pamh);

    if (retval != PAM_SUCCESS) {
        tet_printf(" pam_start returned %s when expected to succeed.",
                                pam_strerror(NULL, retval));
        tet_result(TET_FAIL);
        return;
    }

    tet_result(TET_PASS);
    pam_end(pamh, retval);
    pamh = NULL;
    return;
}


/*
 * tc2() :
 *     This test case checks the interface pam_start with NULL
 *     for the user name. The expected return value is PAM_SUCCESS.
 */

private void
tc2()
{
    int    retval;

    retval = pam_start(conf_file, NULL, &pamc, &pamh);

    if (retval != PAM_SUCCESS) {
        tet_printf(" pam_start returned %s when expected to succeed.",
                                pam_strerror(NULL, retval));
        tet_result(TET_FAIL);
        return;
    }

    tet_result(TET_PASS);
    pam_end(pamh, retval);
    pamh = NULL;
    return;
}


/*
 * tc3() :
 *     This test case checks the interface pam_start with NULL
 *     for the conversation structure. Expected return value is
 *     PAM_BUF_ERR.
 */

private void
tc3()
{
    int    retval;

    retval = pam_start(conf_file, user, NULL, &pamh);

    if (retval != PAM_BUF_ERR) {
        tet_printf(" pam_start returned %s for NULL conv structure", 
                                pam_strerror(NULL, retval));
        tet_infoline(" It was expected to return PAM_BUF_ERR.");
        tet_result(TET_FAIL);

        pam_end(pamh, retval);
        pamh = NULL;
        return;
    }

    tet_result(TET_PASS);
    return;
}


/*
 * tc4() :
 *     This test case checks the interface pam_start with NULL
 *     for the service. The return value should not be PAM_SUCCESS.
 */

/* NOTE: This test is generating SIGSEGV in the tet environment. In
 * normal conditions pam_start fails with PAM_ABORT. Need to check this
 */

/* private void */
/* tc4() */
/* { */
/*     int    retval; */

/*     retval = pam_start(NULL, user, &pamc, &pamh); */

/*     if (retval == PAM_SUCCESS) { */
/*         tet_infoline(" pam_start returned PAM_SUCCESS for NULL service name"); */
/*         tet_infoline(" pam_start not expected to succeed"); */
/*         tet_result(TET_FAIL); */

/*         pam_end(pamh, retval); */
/*         pamh = NULL; */
/*         return; */
/*     } */

/*     tet_result(TET_PASS); */
/*     return; */
/* } */


/*
 * tc5() :
 *     This test case checks the interface pam_start with NULL
 *     for pam handle. The return value should not be PAM_SUCCESS.
 */

/* NOTE: This test is generating SIGSEGV. This is due to a NULL
 * pointer dereferencing in the pam_start code without checking the
 * pointer.
 */

/* cyeoh@samba.org: Segfaulting seems to be valid in this case
	 I will update the assertions to remove this assertion */

/* private void */
/* tc5() */
/* { */
/*     int    retval; */

/*     retval = pam_start(conf_file, user, &pamc, NULL); */

/*     if (retval == PAM_SUCCESS) { */
/*         tet_infoline(" returned PAM_SUCCESS for NULL pam handle"); */
/*         tet_infoline(" pam_start not expected to succeed"); */
/*         tet_result(TET_FAIL); */

/*         pam_end(pamh, retval); */
/*         pamh = NULL; */
/*         return; */
/*     } */

/*     tet_result(TET_PASS); */
/*     return; */
/* } */


/*
 *  delete_tests():
 *       This routine is called to stop execution of the test cases
 *       in case of initialization errors.
 */

private void
delete_tests(char *msg)
{
    int    count;

    for (count = 1; count <= NUM_TESTS; count++) {
        tet_delete(count, msg);
    }

    return;
}
