/*
 * Copyright (c) 2002-2003 WIPRO TECHNOLOGIES 
 * Developed for LSB-PAM project by WIPRO TECHNOLOGIES
 */

/*
 * Project: LSB-PAM
 *
 * File: tset/LSB.pam/testcases/pam_strerror/pam_strerror.c
 * This file contains the test cases for testing the interface
 * pam_strerror.
 *
 * Author(s) : Rohit R <rohit.raveendran@wipro.com>, WIPRO TECHNOLOGIES
 *             Laavanya K R <laavanya.gopalan@wipro.com>, WIPRO TECHNOLOGIES
 *
 * Modifications:
 *
 */

#include <stdio.h>
#include <string.h>
#include <security/pam_appl.h>
#include <security/pam_misc.h>

#include <std.h>
#include <tet_api.h>

/*******************************************************************/

#define MAX_MSG_COUNT (_PAM_RETURN_VALUES+1)
const char *default_message = "Unknown Linux-PAM error";

private void tc1();

private void prepare_tests();
private void clean_tests();

public  void (*tet_startup)() = prepare_tests;
public  void (*tet_cleanup)() = clean_tests;

public struct tet_testlist tet_testlist[] = {
        { tc1, 1 },
        { NULL, 0 }
};

/*******************************************************************/

private void
prepare_tests()
{
    tet_infoline(" starting tests pam_strerror ");
    return;
}


private void
clean_tests()
{
    tet_infoline(" end of tests pam_strerror ");
    return;
}


/*
 * tc1() :
 *     This test case checks the interface pam_strerror with valid
 *     parameters. The strings returned for each return value should
 *     be unique.
 */

private void
tc1()
{
    int    count;
    int    sub_count;
    int    retval;

    const char *messages[MAX_MSG_COUNT];

    for (count = 0; count < MAX_MSG_COUNT; count++) {
        messages[count] = pam_strerror(NULL, count);

        for (sub_count = 0; sub_count < count; sub_count++) {

            retval = strcmp(messages[count], messages[sub_count]);

	    if (retval == 0) {
                    tet_printf(" same string retured for values %d & %d",
                                  count, sub_count);
                    tet_infoline(" pam_strerror failed ");
                    tet_result(TET_FAIL);
                    return;
            }
	}
    }

    tet_result(TET_PASS);
    return;
}


