
/*************************************************************************
*
* Copyright (c) 1997,2005 by The Open Group
*
* All rights reserved.  No part of this source code may be reproduced,
* stored in a retrieval system, or transmitted, in any form or by any
* means, electronic, mechanical, photocopying, recording or otherwise,
* except as stated in the end-user licence agreement, without the prior
* permission of the copyright owners.
*
* Motif (R) and UNIX (R) are registered trademarks and 'IT DialTone' (TM),
* 'The Open Group' (TM) and the 'X Device' (TM) are trademarks of
* The Open Group.
*
*
*	testset for tset/PTHR.os/all/sigwait_exectests
*
*	Written by Mount Bonnell Inc. Austin, Texas, USA
*	$Id: sigwait_exectests.c,v 1.1 2005/01/19 11:02:21 ajosey Exp $
*
*	History:
*	Created separate executable to avoid calls to non-asynch safe functions.
*
*
*************************************************************************/

#if	( TEST_XPG <= 4 )
#include	<sys/types.h>	/* needed for pthread types in POSIX96 mode */
#endif
#include	<ctype.h>
#include	<errno.h>
#include	<pthread.h>
#include	<signal.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<sys/types.h>
#include	<time.h>
#include	<unistd.h>

#include	"tet_api.h"
#include	"vsth/vsth.h"
#include	"vsth/vsth_fw.h"

#ifdef  UNDEF_MACROS
#undef  sigwait
#endif

void	t5_c1();
void *  t5_t1(void *);
#if (TEST_XPG > 0 || _POSIX_C_SOURCE >= 200112) \
	|| defined(_POSIX_JOB_CONTROL)
void	t5_c2();
void *  t5_t2(void *);
#endif

int	tet_nosigreset = 0;

int
tet_main( int argc, char **argv)
{

	if (argc >= 1)
	{
		switch (atoi(argv[1]))
		{
		case 501:
			t5_c1();
			break;

#if (TEST_XPG > 0 || _POSIX_C_SOURCE >= 200112) \
	|| defined(_POSIX_JOB_CONTROL)
		case 502:
			t5_c2();
			break;
#endif

		default:
			tet_printf("Unexpected argument %d to exectests",
				atoi(argv[1]));
		}
	}
	else
		tet_printf("Incorrect number of arguments to exectests");

	exit(1);
}

/******	Test the process termination case.
	Set the default behavior for SIGTERM then create a thread.
	The thread sends itself a SIGTERM. Our parent will
	check that the process exited appropriately.		******/

void
t5_c1()
{
	int			rval;
	pthread_t		tid;
	void			*tval;
	struct sigaction	sa;

	/* set SIGTERM action to SIG_DFL */

	rval = sigfillset( &sa.sa_mask );
	if ( rval != 0 )
	{
		tet_printf("sigfillset failed, errno == %d", errno);
		exit(1);
	}

	sa.sa_flags	= 0;
	sa.sa_handler	= SIG_DFL;

	rval = sigaction( SIGTERM, &sa, NULL );
	if ( rval != 0 )
	{
		tet_printf("sigaction failed, errno == %d", errno);
		exit(1);
	}

	rval = vsth_pthread_create( &tid, NULL, t5_t1, NULL );
	if ( rval != 0 )
	{
		tet_printf("vsth_pthread_create failed, rval == %d", rval);
		exit(1);
	}

	/* pause(); */
	(void) vsth_pthread_join(tid, &tval);
	exit(2);
}


#if (TEST_XPG > 0 || _POSIX_C_SOURCE >= 200112) \
	|| defined(_POSIX_JOB_CONTROL)

/******	Test the SIGSTOP/SIGCONT case.
        Create a thread.  The thread sends itself a SIGSTOP. Our parent
	obtains the child process status and then continues the thread
	with a SIGCONT. We join the thread and exit. Our parent again
	obtains the child process status. 	******/


int			T5_flag;
pthread_t		T5_tid;
pthread_mutex_t		T5_mx	= PTHREAD_MUTEX_INITIALIZER;
pthread_cond_t		T5_cv	= PTHREAD_COND_INITIALIZER;

void
t5_c2()
{
	int		rval;
	void		*tval;

	T5_flag = 0;

	rval = pthread_mutex_lock( &T5_mx );
	if ( rval != 0 )
	{
		vsth_surprise("pthread_mutex_lock", 0, rval, NULL);
		exit(1);
	}

	rval = vsth_pthread_create( &T5_tid, NULL, t5_t2, NULL );
	if ( rval != 0 )
	{
		vsth_surprise("vsth_pthread_create", 0, rval, NULL);
		exit(1);
	}

	while ( ! T5_flag )
	{
		rval = pthread_cond_wait( &T5_cv, &T5_mx );
		if ( rval != 0 )
		{
			vsth_surprise("pthread_cond_wait", 0, rval, NULL);
			(void) pthread_cancel( T5_tid );
			(void) vsth_pthread_detach( T5_tid );
			exit(1);
		}
	}

	rval = pthread_mutex_unlock( &T5_mx );
	if ( rval != 0 )
	{
		vsth_surprise("pthread_mutex_unlock", 0, rval, NULL);
	}

	rval = vsth_pthread_join( T5_tid, &tval );
	if ( rval == 0 )
	{
		exit((int) tval);
	}
	else
	{
		(void) pthread_cancel( T5_tid );
		(void) vsth_pthread_detach( T5_tid );
		vsth_surprise("vsth_pthread_join", 0, rval, NULL);
		exit(1);
	}
}

#endif	/* _POSIX_JOB_CONTROL */

void *
t5_t1( void *arg )
{
	int		rval;
	int		nerrs;
	int		nfails;
	void		*tval;

	nerrs	= 0;
	nfails	= 0;
	tval	= (void *) 1;

	rval = pthread_kill( pthread_self(), SIGTERM );
	if ( rval != 0 )
	{
		vsth_surprise("pthread_kill", 0, rval, &nerrs);
	}

	if ( nfails )
		tval = (void *) 2;
	else if (( nerrs == 0 ) && ( nfails == 0 ))
		tval = NULL;

	pthread_exit(tval);

	/* NOTREACHED */
	return(tval);
}

#if (TEST_XPG > 0 || _POSIX_C_SOURCE >= 200112) \
	|| defined(_POSIX_JOB_CONTROL)

void *
t5_t2( void *arg )
{
	int		rval;
	int		nerrs;
	int		nfails;
	void		*tval;

	nerrs	= 0;
	nfails	= 0;
	tval	= (void *) 1;

	rval = pthread_mutex_lock( &T5_mx );
	if ( rval == 0 )
	{

		++T5_flag;
	
		rval = pthread_cond_signal( &T5_cv );
		if ( rval != 0 )
		{
			vsth_surprise("pthread_cond_signal", 0, rval, &nerrs);
		}
	
		rval = pthread_kill( pthread_self(), SIGSTOP );
		if ( rval != 0 )
		{
			vsth_surprise("pthread_kill", 0, rval, &nerrs);
		}
	
		rval = pthread_mutex_unlock( &T5_mx );
		if ( rval != 0 )
		{
			vsth_surprise("pthread_mutex_unlock", 0, rval, &nerrs);
		}
	}
	else
	{
		vsth_surprise("pthread_mutex_lock", 0, rval, &nerrs);
	}

	if ( nfails )
		tval = (void *) 2;
	else if (( nerrs == 0 ) && ( nfails == 0 ))
		tval = NULL;

	pthread_exit(tval);

	/* NOTREACHED */
	return(tval);
}

#endif	/* _POSIX_JOB_CONTROL */


